#########################################################################
## 
## Working Paper : Bridging Conflicts and Biodiversity Protection 
## 2025-02
##
#########################################################################

get_current_file_path <- function(){
  this_file <- grep("^--file=", commandArgs(), value = TRUE)
  this_file <- gsub("^--file=", "", this_file)
  if (length(this_file) == 0) this_file <- rstudioapi::getSourceEditorContext()$path
  return(dirname(this_file))
}

# set working directory
wkdir <- get_current_file_path()
print(wkdir)
setwd(wkdir)

gitdir <- wkdir
localdir <- file.path(wkdir,'local_data')
figdir <- file.path(wkdir,'figures',sprintf("vers%s",Sys.Date()))
xfun::dir_create(figdir)
tbldir <- file.path(wkdir,'tables',sprintf("vers%s",Sys.Date()))
xfun::dir_create(tbldir)
outdir <- file.path(wkdir,'output',sprintf("vers%s",Sys.Date()))
xfun::dir_create(outdir)

run_vers <- '2024-04-16'
ddh_vers <- '2024-08-12'
master_vers <- '2024-07-22'
admin_vers <- '2024-05-09'
tfddspgrp_vers <- '2025-02-17'
iucn_vers <- '2022-2'

ddhdir <- file.path(localdir,sprintf("vers%s",ddh_vers))

setwd(wkdir)
source(file.path(wkdir,'biod_intl_wp_global_libraries.R'))
sf_use_s2(FALSE)

# renv
#renv::init()

# load boundaries for maps
#source(file.path(wkdir,'biod_intl_wp_load_boundary_data.R')) # does not run without restricted data
#print("loading boundary data")

source(file.path(wkdir,'biod_intl_wp_load_gridded_pop_data.R'))
print("loading gridded pop data")

##
## tables
##

# tab species info
#master_tab_fn <- file.path(wkdir,'local_data','tab_data',sprintf('master_species_x_country%s.dta',master_vers)) 
#master_tab <- haven::read_dta(master_tab_fn) # does not run without restricted data
#names(master_tab)

desired_species_group_order <- c('Terrestrial Vertebrates','Fish',
                                 'Arthropods','Mollusca',
                                 'Other Animals','Vascular Plants','Fungi',
                                 'Other non-animal non-plant species')

desired_continent_order <- c("Africa",
                            "Asia",
                            "Europe",
                            "North America",
                            "Oceania",
                            "South America",
                            "Across continents")

# Species information and data for Figure 1 Figure 8
source(file.path(wkdir,'species_info_all.R'))

# FCV FY 2024
source(file.path(wkdir,'species_info_by_fcv_territories.R'))

# Non determined legal status 
source(file.path(wkdir,'species_info_by_ndls_territories.R'))

# Joint-regime (EEZ) territories, 
source(file.path(wkdir,'species_info_by_joint_territories.R'))

# River basins
source(file.path(wkdir,'species_info_by_international_river_basins.R'))

# River basins X species groups
source(file.path(wkdir,'species_info_by_international_river_basins_x_species_groups.R'))

# river basins by treaty or not
source(file.path(wkdir,'species_info_by_treaty_of_any_international_river_basins.R'))

gc()

##
## list of unique species occurrence region overlay with
## geographic union of groups
##
source(file.path(wkdir,'species_info_by_geographic_union_groups.R'))

gc() 

##
## Table 1 : Area, human population count (WorldPop) and 
##            total species in geopolitically overlapping areas
# does not run with restricted data
#source(file.path(wkdir,'biod_intl_wp_tbl01_pop_and_area_and_totspp_info_by_geo_groups.R'))

## Table 2 : 
# does not run with restricted data
#source(file.path(wkdir,'biod_intl_wp_tbl02_spp_info_by_geo_groups.R'))

## Table 3 : Transboundary river basins:  
#               species covered by treaties and river basin organizations 
#source(file.path(wkdir,'biod_intl_wp_tbl03_spp_info_by_basin.R'))

## Figure 1: see excel

## Figure 2 : Selected species occurrence regions
source(file.path(wkdir,'biod_intl_wp_fig02_species_map_example.R'))

## Figure 3 : Countries determined as Fragile and Conflict-affected 
##              Situations areas (FCS) in 2024
# does not run without restricted data
#source(file.path(wkdir,'biod_intl_wp_fig03_country_in_fcs.R'))

## Figure 4 : Log human population density in transboundary river basins
source(file.path(wkdir,'biod_intl_wp_fig04_human_pop_in_transboundary_basins.R'))

## Figure 5 : Total count of critical species in geopolitically overlapping areas
source(file.path(wkdir,'biod_intl_wp_fig05_venn_diagram_GSOA_species.R'))

## Figure 6 : Critical species in geopolitically sensitive and overlapping areas (GSOA) 
##              and other areas
# input data for non Geographically Overlapping Areas
source(file.path(wkdir,'biod_intl_wp_fig06__data_venn_diagram_non_GSOA_species.R'))
# construct figure 
source(file.path(wkdir,'biod_intl_wp_fig06_venn_diagram_other_and_GSOA_species.R'))

## Figure 7 : see excel