##
## Figure 2: Selected species occurrence regions
##

# Species list
species_list <- c('Lagidium viscacia','Scherya bahiensis')

print(sprintf("%s species in list",length(species_list)))

# load species shapes from species listed in xlsx
species_sf_fn <- file.path(wkdir,'local_data','geo_data','species_occurrence_region_examples.shp')
if(!file.exists(species_sf_fn)){
  source(file.path(wkdir,'biod_intl_wp_load_species_shapefiles.R'))  
} else {
  species_sf <- st_read(species_sf_fn)
}


# add
species_sf <- species_sf %>%
  dplyr::mutate(species_type = case_when(
    species == 'Scherya bahiensis' ~ 'endemic',
    species == 'Lagidium viscacia' ~ 'non-endemic',
    TRUE ~ 'other'))

windowsFonts("Arial" = windowsFont("Arial"))
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'white')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

bndp_sa <- bndp %>%
  dplyr::filter(Continent == 'South America')

bndp_lac <- bnd_ply %>%
  dplyr::filter(WB_REGION == 'LAC')

bbox_lac <- st_bbox(bndp_lac)
bbox_lac["ymax"] <- 15
bbox_lac["xmin"] <- -92
bndp_lac_crop <- st_crop(bndp_lac,bbox_lac)

lineT<- c("countries"="solid", "disputed" = "dotdash","ocean" = "solid")

crs_ekIV <- "+proj=eck4 +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs" 

bndp_lac_ekIV <- st_transform(bndp_lac_crop,crs = crs_ekIV)
bbox <- st_bbox(bndp_lac_ekIV)

bnd_ply_ekIV <- st_transform(st_crop(bnd_ply,bndp_lac),crs = crs_ekIV)
species_sf_ekIV <- st_transform(species_sf,crs = crs_ekIV)
species_sf_buf_ekIV <- st_buffer(species_sf_ekIV %>% 
                                   dplyr::filter(species == "Scherya bahiensis") %>%
                                   st_centroid(),
                                 100000)

bndline_ekIV <- st_transform(st_crop(bndline_map,bndp_lac), crs = crs_ekIV)

#load admin 1
brazil_adm1 <- st_read(file.path(wkdir,'local_data','geo_data','BRA_adm1.shp')) %>%
  dplyr::filter(NAME_1 == "Bahia")
brazil_adm1_ekIV <- st_transform(brazil_adm1,crs = crs_ekIV)
ocean_ekIV <- st_transform(grid_sf,crs = crs_ekIV)

# map
# Occurrence Regions of Selected Endemic and Non-Endemic Species
p_sor <- ggplot() +
  geom_sf(data=ocean_ekIV, fill = "aliceblue", color = 'white') +
  geom_sf(data = bnd_ply_ekIV, color = 'grey90') +
  geom_sf(data = species_sf_buf_ekIV, color = 'red',fill=NA) +
  ggnewscale::new_scale_fill()+
  geom_sf(data = species_sf_ekIV, aes(fill=species),color=NA,alpha = 0.9) +
  scale_fill_manual(values = c("Scherya bahiensis" = "red",
                               "Lagidium viscacia" = "darkgreen"),
                    name = "Species\nOccurrence\nRegion",
                    labels = function(x) str_wrap(x, width = 10)) +
  geom_sf(data=bndline_ekIV, aes(linetype = bndtype, color = colortype), fill = NA,
          lwd=0.1,show.legend = FALSE) +
  scale_color_manual(values = c("land" = "gray80","ocean"="#ADD8E6"))+
  scale_linetype_manual(values = lineT) +
  
  coord_sf(xlim = c(bbox["xmin"], bbox["xmax"]),
           ylim = c(bbox["ymin"], bbox["ymax"]),
           expand = FALSE  # To prevent any additional padding around the edges
  ) +
  mytheme +
  labs(fill = "") +
  # drop axis labels per reviewer comment
  theme(legend.position="right",
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank(),
        legend.text = element_text(face = "italic"),
        #legend.spacing = unit(12, "lines")  # Space between legend items
        legend.key.height = unit(2, "lines")
        ) +
  #theme(legend.key = element_rect(fill = "white")) +
  theme(strip.background =element_rect(fill="gray92"))

p_sor_fn <- file.path(figdir,paste0('fig_02_species_occurrence_regions_examples',Sys.Date(),'.png'))
ggsave(p_sor_fn, p_sor, dpi=500, width = 5, height = 5, units='in')
