################################################################################
#
# Figure 3: Countries determined as Fragile and Conflict-affected Situations areas (FCS) in 2024
#
################################################################################

figvers <- file.path(wkdir,'figures',sprintf("vers%s",Sys.Date()))
xfun::dir_create(figvers)

# FCV entities
fcv_entity_fn <- file.path(wkdir,'local_data','tab_data','fcv.xlsx')
fcv_entity <- readxl::read_excel(fcv_entity_fn) %>%
  dplyr::rename(WB_ISO = WB_IS0)

bnd_ply_map_fcs <- merge(bnd_ply_map,fcv_entity,by='WB_ISO')

bnd_ply_fcs_disp_ekIV <- st_read(file.path(wkdir,'local_data','geo_data','Boundary_Data_50mil','ne_50m_WB2019_admin_0_disputed.shp')) %>%
  dplyr::filter(WB_NAME=='Abyei')

table(bndline$bndtype)
table(bndline$colortype)
lineT<- c("countries"="solid", "disputed" = "dotdash","ocean" = "solid")

# Define custom labeller function
custom_labeller <- function(variable, value) {
  value
}

windowsFonts("Arial" = windowsFont("Arial"))
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'white')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)
# PROJ.4 string for Eckert IV projection
crs_ekIV <- "+proj=eck4 +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs" 
bnd_ply_fcs_ekIV <- st_transform(bnd_ply_map_fcs, crs = crs_ekIV)
bnd_ply2_ekIV <- st_transform(bnd_ply %>% st_cast(.,"MULTIPOLYGON") %>% 
                               st_cast(.,"POLYGON"), crs = crs_ekIV)
bnd_ply_ekIV <- st_transform(bnd_ply_map %>% st_cast(.,"MULTIPOLYGON") %>% 
                             st_cast(.,"POLYGON"), crs = crs_ekIV)
bndline_ekIV <- st_transform(bndline, crs = crs_ekIV)
ocean_ekIV <- st_transform(grid_sf,crs = crs_ekIV)
bbox_ekIV <- st_bbox(bnd_ply_ekIV)
bbox_ekIV["ymin"]=bbox_ekIV["ymin"] + 800000

# plot fcs 2024
p_fcs <- ggplot() +
  geom_sf(data=ocean_ekIV, fill = "aliceblue", color = NA) +
  geom_sf(data=bnd_ply_ekIV, fill='gray80', color = NA) +
  geom_sf(data=bnd_ply_fcs_disp_ekIV, aes(fill='FCS (2024)'), color = NA) +
  geom_sf(data=bnd_ply_fcs_ekIV, aes(fill='FCS (2024)'), color = NA) +
  scale_fill_manual(name = "", values = c("FCS (2024)" = "red")) +
  geom_sf(data=bndline_ekIV, aes(linetype = bndtype, color = colortype), fill = NA,
          lwd=0.1,show.legend = FALSE) +
  scale_color_manual(values = c("land" = "gray80","ocean"="#ADD8E6"))+
  scale_linetype_manual(values = lineT) +
  coord_sf(xlim = c(bbox_ekIV["xmin"], bbox_ekIV["xmax"]), 
           ylim = c(bbox_ekIV["ymin"], bbox_ekIV["ymax"])) +
  mytheme +
  # drop axis labels per reviewer comment
  theme(legend.position="bottom",
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank()) +
  theme(legend.key = element_rect(fill = "white")) +
  theme(strip.background =element_rect(fill="gray92"))

p_fcs_fn <- file.path(figdir,
                         sprintf('fig_03_countries_fcs_%s.png',Sys.Date()))
ggsave(p_fcs_fn,p_fcs,width= 6, height = 4)
