################################################################################
#
# Figure 4: Log human population density in transboundary river basins
#
################################################################################

## basins
tfdd_fn <- file.path(wkdir,'local_data','geo_data','TFDD_SpatialData_Public202203','BasinMaster311_20220224.shp')
tfdd_raw <- read_sf(tfdd_fn)
tfdd <- st_transform(tfdd_raw,4326) %>%
  mutate(bid = row_number()) %>%
  dplyr::select(BCODE,Basin_Name,Continent_,Area_km2,bid)

tfdd$wpop2020 <- exactextractr::exact_extract(wpop20, tfdd, 'sum')

tfdd_out <- tfdd %>%
  dplyr::rename(area_km2 = Area_km2) %>%
  dplyr::select(BCODE,Basin_Name,wpop2020,area_km2)

# aggregate
tfdd_out_total <- tfdd_out %>%
  dplyr::group_by(BCODE,Basin_Name) %>%
  dplyr::summarise(area_km2 = sum(area_km2),
                   wpop2020 = sum(wpop2020),
                   ln_wpop2020 = log(sum(wpop2020)+1)) %>%
  st_as_sf()

tfdd_out_total <- tfdd_out_total %>%
  dplyr::mutate(wpopden2020 = wpop2020 / area_km2) %>%
  dplyr::mutate(ln_wpopden2020 = log(wpopden2020 + 1))
  
lineT<- c("countries"="solid", "disputed" = "dotdash","ocean" = "solid")

# Define custom labeller function
custom_labeller <- function(variable, value) {
  value
}

palette <- brewer.pal(9, "YlOrRd")  # 9 color shades of yellow-to-red

# Create breaks or bins for your data
breaks_log <- pretty(tfdd_out_total$ln_wpopden2020, n = 5)  # `pretty()` helps to generate nice breaks

windowsFonts("Arial" = windowsFont("Arial"))
mytheme <- theme(text = element_text(family = 'Arial')
                 ,panel.background = element_rect(fill = 'white')
                 ,plot.title = element_text(size = 32)
                 ,plot.subtitle = element_text(size = 14)
                 ,axis.title = element_blank()
                 ,axis.text = element_blank()
)

# PROJ.4 string for Eckert IV projection
crs_ekIV <- "+proj=eck4 +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs" 
bnd_ply_ekIV <- st_transform(bnd_ply_map, crs = crs_ekIV)
tfdd_out_total_ekIV <- st_transform(tfdd_out_total, crs = crs_ekIV)
bndline_ekIV <- st_transform(bndline_map %>% dplyr::filter(colortype=='ocean'), crs = crs_ekIV)
ocean_ekIV <- st_transform(grid_sf,crs = crs_ekIV)
bbox <- st_bbox(bnd_ply_ekIV)

# plot population total
p_popden <- ggplot() +
  geom_sf(data=ocean_ekIV, fill = "aliceblue", color = NA) +
  geom_sf(data=bnd_ply_ekIV, fill='gray80', color = NA) +
  geom_sf(data=tfdd_out_total_ekIV, aes(fill=ln_wpopden2020)) +
  scale_fill_gradientn(colors = palette,  # Apply the color palette
                       breaks = breaks_log,  # Use breaks for the legend
                       #labels = scales::comma(),
                       name='Ln population density') +  # Optionally format labels
  geom_sf(data=bndline_ekIV %>% dplyr::filter(colortype == 'ocean'), aes(linetype = bndtype, color = colortype), fill = NA,
          lwd=0.1,show.legend = FALSE) +
  scale_color_manual(values = c("land" = "gray80","ocean"="#ADD8E6"))+
  scale_linetype_manual(values = lineT) +
  coord_sf(xlim = c(bbox["xmin"], bbox["xmax"]), ylim = c(bbox["ymin"], bbox["ymax"])) +
  mytheme +
  # drop axis labels per reviewer comment
  theme(legend.position="bottom",
        axis.text.x = element_blank(),
        axis.text.y = element_blank(),
        axis.ticks = element_blank()) +
  theme(legend.key = element_rect(fill = "white")) +
  theme(strip.background =element_rect(fill="gray92")) +
  guides(fill=guide_coloursteps(title.position="top",even.steps=FALSE))

p_popden_fn <- file.path(figdir,
                         sprintf('fig_04_popden_in_transboundary_basins_%s.png',Sys.Date()))
ggsave(p_popden_fn,p_popden,width= 6, height = 4)
