##
## Figure 5:  Total count of critical species in geopolitically sensitive and overlapping areas
##

p5_fn <- file.path(figdir,sprintf('fig_05_species_GSOA_venn_diag%s.png',Sys.Date()))

##
## JOINT GID
##
bnddisp <- bndp %>%
  dplyr::filter(bndtype=="joint") %>%
  st_drop_geometry()

jointterr_entity_gid <- bnddisp %>%
  dplyr::select(gid) %>%
  pull()

##
## disputed GID
##
bnddisp_df <- bndp %>%
  dplyr::filter(bndtype=="disputed")  %>%
  st_drop_geometry()

dispterr_entity_gid <- bnddisp_df %>%
  dplyr::select(gid) %>%
  pull()

##
## FCV GID
##

# FCV entities
fcv_entity_fn <- file.path(file.path(localdir,'tab_data','fcv.xlsx'))
fcv_entity <- readxl::read_excel(fcv_entity_fn) %>%
  dplyr::rename(WB_ISO = WB_IS0)
fcv_entity_ids <- fcv_entity %>%
  dplyr::select(gid) %>%
  pull()

## Union of GIDs ##
union_gid <- sort(unique(c(jointterr_entity_gid,dispterr_entity_gid,fcv_entity_ids)))


## basins
tfdd_fn <- file.path(localdir,'geo_data','TFDD_SpatialData_Public202203','BasinMaster311_20220224.shp')
tfdd_raw <- read_sf(tfdd_fn)
tfdd <- st_transform(tfdd_raw,4326) %>%
  mutate(bid = row_number()) %>%
  dplyr::select(BCODE,Basin_Name,Continent_,Area_km2,bid)

tfdd_bid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::select(bid) %>%
  pull()

union_bid <- sort(unique(tfdd_bid))

##
## Any species in areas
##
master_tab_all_venn_GSA <- master_tab %>%
  dplyr::filter(!is.na(area)) %>%
  dplyr::filter(!is.na(pthreat)) %>%
  dplyr::filter(!is.na(d_endemic100)) %>%
  dplyr::select(species,d_endemic100,area,pthreat,basin_bids, entity_ids) %>%
  # Produce statistics for entire set of geographic areas (union) #
  distinct() %>%
  
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  
  # gid ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  
  # in basin OR country
  dplyr::filter((basin_bids %in% c(union_bid)) | (entity_ids %in% c(union_gid))) %>%
  
  # drop identifiers and keep distinct rows
  dplyr::select(-c(entity_ids,basin_bids)) %>%
  distinct() %>%
  
  # take largest area for species level
  group_by(species,pthreat,d_endemic100) %>%
      dplyr::summarize(d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE),
                   area = max(area,na.rm=TRUE)) %>%
  ungroup() %>%

  dplyr::select(species,d_endemic100,area,pthreat) %>%
  
  distinct() %>%
  mutate(spp_smallocc50 = ifelse(area <= 50*50,species,NA),
         spp_tprob80 = ifelse(pthreat >= 80,species,NA),
         spp_endemic100 = ifelse(d_endemic100 ==1,species,NA)
  ) %>%
  dplyr::select(species, spp_smallocc50, spp_tprob80, spp_endemic100)

# Convert to logical (TRUE/FALSE)
master_tab_all_venn_GSA$A <- !is.na(master_tab_all_venn_GSA$spp_endemic100)
master_tab_all_venn_GSA$B <- !is.na(master_tab_all_venn_GSA$spp_smallocc50)   
master_tab_all_venn_GSA$C <- !is.na(master_tab_all_venn_GSA$spp_tprob80)

print(sprintf("Count of endemic (100) species  = %s",sum(master_tab_all_venn_GSA$A,na.rm = TRUE)))
print(sprintf("Count of species small occ 50x50 = %s",sum(master_tab_all_venn_GSA$B,na.rm = TRUE)))
print(sprintf("Count of species tprob80 = %s",sum(master_tab_all_venn_GSA$C,na.rm = TRUE)))

df_venn <- master_tab_all_venn_GSA %>%
  dplyr::select(A,B,C)

# Plot the Venn diagram
p5 <- ggplot() +
  geom_venn(data=df_venn, aes(A = A, B = B, C = C),
            set_names = NULL,
            fill_color = c("#33CCCC", "#F1CC4F", "#FDA6A6"), # Customize colors for each circle
            fill_alpha = 0.5,
            stroke_color = NA,
            stroke_size = 0,
            show_outside = c("none"),
            text_size = 4,
            set_name_color='white',
              show_percentage = FALSE) +
  labs(fill = NULL) +  
  
  ggnewscale::new_scale_color() +
  geom_point(aes(x=5,y=5,color = "A"),
             size = 4,
             show.legend = TRUE) +  # Blank data layer for legend entry
  geom_point(aes(x=5,y=5,color = "B"),
             size = 4,
             show.legend = TRUE) +  # Blank data layer for legend entry
  geom_point(aes(x=5,y=5,color = "C"),
             size = 4,
             show.legend = TRUE) +  # Blank data layer for legend entry
  scale_color_manual(
    values = c("A" = "#33CCCC", "B"= "#F1CC4F", "C" = "#FDA6A6"),  # Colors for the stages
    labels = c("Endemic", 
               "Small Occurrence Region", 
               "Extinction Threat Indicator")
    
  ) + 
  coord_fixed(xlim = c(-2,2), ylim =  c(-2,2), expand = FALSE) +
  guides(fill = guide_legend(title = 'Title')) +
  theme(
    legend.position = "right",  # Position legend to the right
    legend.title = element_blank(),  # Optionally remove legend title
    legend.key.size = unit(1, "lines"),  # Adjust size of legend keys (optional)
    legend.text = element_text(size = 12),
    legend.spacing.x = unit(1, "lines"),
    panel.grid = element_blank(),
    panel.background = element_rect(fill = "white"),
    plot.background = element_rect(fill = "white"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_blank(),
    axis.text.y = element_blank(),
    axis.ticks = element_blank()  # Remove axis ticks
  )
p5

ggsave(p5_fn,p5, width = 6, height = 3.5)