##
## Input data for Figure 6
##

##
## JOINT GID
##
bnddisp <- bndp %>%
  dplyr::filter(bndtype=="joint") %>%
  st_drop_geometry()

jointterr_entity_gid <- bnddisp %>%
  dplyr::select(gid) %>%
  pull()

##
## disputed GID
##
bnddisp_df <- bndp %>%
  dplyr::filter(bndtype=="disputed")  %>%
  st_drop_geometry()

dispterr_entity_gid <- bnddisp_df %>%
  dplyr::select(gid) %>%
  pull()

##
## FCV GID
##

# FCV entities
fcv_entity_fn <- file.path(localdir,'tab_data','fcv.xlsx')
fcv_entity <- readxl::read_excel(fcv_entity_fn) %>%
  dplyr::rename(WB_ISO = WB_IS0)
fcv_entity_ids <- fcv_entity %>%
  dplyr::select(gid) %>%
  pull()

## Union of GIDs ##
union_gid <- sort(unique(c(jointterr_entity_gid,dispterr_entity_gid,fcv_entity_ids)))


## basins
tfdd_fn <- file.path(localdir,'geo_data','TFDD_SpatialData_Public202203','BasinMaster311_20220224.shp')
tfdd_raw <- read_sf(tfdd_fn)
tfdd <- st_transform(tfdd_raw,4326) %>%
  mutate(bid = row_number()) %>%
  dplyr::select(BCODE,Basin_Name,Continent_,Area_km2,bid)

tfdd_bid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::select(bid) %>%
  pull()

union_bid <- sort(unique(tfdd_bid))

##
## species that are not in gsa areas
##
master_tab_all_venn_non_GSA <- master_tab %>%
  dplyr::filter(!is.na(area)) %>%
  dplyr::filter(!is.na(pthreat)) %>%
  dplyr::filter(!is.na(d_endemic100)) %>%
  dplyr::select(species,d_endemic100,area,pthreat,basin_bids, entity_ids) %>%
  # Produce statistics for entire set of geographic areas (union) #
  distinct() %>%
  
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  
  # gid ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  
  # in basin OR country not in geographically overlapping areas
  dplyr::mutate(d_gsa = ifelse((basin_bids %in% c(union_bid)) | (entity_ids %in% c(union_gid)),
                               1,0)) %>%
  
  # drop identifiers and keep distinct rows
  dplyr::select(-c(entity_ids,basin_bids)) %>%
  distinct() %>%
  
  # take largest area for species level
  #group_by(species) %>%
  #slice_max(area, n = 1, na_rm = TRUE) %>%
  #dplyr::ungroup() %>%
  
  group_by(species,pthreat,d_endemic100) %>%
  dplyr::summarize(d_gsa = sum(d_gsa,na.rm=TRUE),
                   d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE),
                   area = max(area,na.rm=TRUE)) %>%
  ungroup() %>%
  dplyr::filter(d_gsa == 0) %>%
  dplyr::select(species,d_endemic100,area,pthreat,d_gsa) %>%
  
  distinct() %>%
  mutate(spp_smallocc50 = ifelse(area <= 50*50,species,NA),
         spp_tprob80 = ifelse(pthreat >= 80,species,NA),
         spp_endemic100 = ifelse(d_endemic100 ==1,species,NA)
  ) %>%
  dplyr::select(species, spp_smallocc50, spp_tprob80, spp_endemic100)

# Convert to logical (TRUE/FALSE)
master_tab_all_venn_non_GSA$A <- !is.na(master_tab_all_venn_non_GSA$spp_endemic100)
master_tab_all_venn_non_GSA$B <- !is.na(master_tab_all_venn_non_GSA$spp_smallocc50)   
master_tab_all_venn_non_GSA$C <- !is.na(master_tab_all_venn_non_GSA$spp_tprob80)

print(sprintf("Sum of endemic (100) species not in GSOA  = %s",sum(master_tab_all_venn_non_GSA$A,na.rm = TRUE)))
print(sprintf("Sum of species small occ 50x50 not in GSOA = %s",sum(master_tab_all_venn_non_GSA$B,na.rm = TRUE)))
print(sprintf("Sum of species tprob80 not in GSOA = %s",sum(master_tab_all_venn_non_GSA$C,na.rm = TRUE)))

df_venn_nonGOA <- master_tab_all_venn_non_GSA %>%
  dplyr::select(A,B,C)
df_venn_nonGOA2 <- as.data.frame(df_venn_nonGOA)

#for table colnames
df_venn_nonGOA2$A <- ifelse(df_venn_nonGOA2$A==TRUE,"Endemic100",FALSE)
df_venn_nonGOA2$B <- ifelse(df_venn_nonGOA2$B==TRUE,"Small50",FALSE)
df_venn_nonGOA2$C <- ifelse(df_venn_nonGOA2$C==TRUE,"Threat80",FALSE)

# Create a factor of all combinations
combinations <- interaction(df_venn_nonGOA2$A, df_venn_nonGOA2$B, df_venn_nonGOA2$C)

# Count the number of occurrences for each combination
comb_counts <- table(combinations)

# replace varname 
names(comb_counts) <- gsub("\\.","_",names(comb_counts))
names(comb_counts)[names(comb_counts)=="FALSE_FALSE_FALSE"] <- "None"
names(comb_counts) <- gsub("_FALSE","",names(comb_counts))
names(comb_counts) <- gsub("FALSE_","",names(comb_counts))
names(comb_counts)

# output
df_fig06_venn_non_GOA_data <- comb_counts %>% as.data.frame()
colnames(df_fig06_venn_non_GOA_data) <- c("SpeciesType","SpeciesCount")
df_fig06_venn_non_GOA_data <- df_fig06_venn_non_GOA_data %>%
  dplyr::mutate(geography = "Not in Geographically Overlapping Areas")
df_fig06_venn_non_GOA_data_fn <- file.path(figdir,'fig_06_venn_non_GSOA_data.csv')
write.csv(df_fig06_venn_non_GOA_data,df_fig06_venn_non_GOA_data_fn,row.names = FALSE)