##
## Figure 6:  Critical species in geopolitically sensitive and overlapping areas (GOSA) and other areas (Other)
##

p6_fn <- file.path(figdir,sprintf('fig_06_species_GSOA_or_not_venn_diagram%s.png',Sys.Date()))

##
## import input for non GOA species venn
##
df_fig06_venn_non_GOA_data_fn <- file.path(figdir,'fig_06_venn_non_GSOA_data.csv')
if(!file.exists(df_fig06_venn_non_GOA_data_fn)){
  print("run input")  
} 
df_fig06_venn_non_GOA_data <- read.csv(df_fig06_venn_non_GOA_data_fn)

# assign 
ellipse_endemic_value <- df_fig06_venn_non_GOA_data %>% 
  dplyr::filter(SpeciesType %in% c('Endemic100','Endemic100_Small50',
                                   'Endemic100_Threat80',
                                   'Endemic100_Small50_Threat80')) %>% 
  summarize(sum(SpeciesCount,na.rm=TRUE)) %>% pull()
ellipse_small_value <- df_fig06_venn_non_GOA_data %>%
  dplyr::filter(SpeciesType %in% c('Small50','Endemic100_Small50',
                                   'Small50_Threat80',
                                   'Endemic100_Small50_Threat80')) %>% 
  summarize(sum(SpeciesCount,na.rm=TRUE)) %>% pull()
ellipse_eti_value <- df_fig06_venn_non_GOA_data %>%
  dplyr::filter(SpeciesType %in% c('Threat80','Small50_Threat80',
                                   'Endemic100_Threat80',
                                   'Endemic100_Small50_Threat80')) %>% 
  summarize(sum(SpeciesCount,na.rm=TRUE)) %>% pull()
  
##
## JOINT GID
##
bnddisp <- bndp %>%
  dplyr::filter(bndtype=="joint") %>%
  st_drop_geometry()

jointterr_entity_gid <- bnddisp %>%
  dplyr::select(gid) %>%
  pull()

##
## disputed GID
##
bnddisp_df <- bndp %>%
  dplyr::filter(bndtype=="disputed")  %>%
  st_drop_geometry()

dispterr_entity_gid <- bnddisp_df %>%
  dplyr::select(gid) %>%
  pull()

##
## FCV GID
##

# FCV entities
fcv_entity_fn <- file.path(localdir,'tab_data','fcv.xlsx')
fcv_entity <- readxl::read_excel(fcv_entity_fn) %>%
  dplyr::rename(WB_ISO = WB_IS0)
fcv_entity_ids <- fcv_entity %>%
  dplyr::select(gid) %>%
  pull()

## Union of GIDs ##
union_gid <- sort(unique(c(jointterr_entity_gid,dispterr_entity_gid,fcv_entity_ids)))


## basins
tfdd_fn <- file.path(localdir,'geo_data','TFDD_SpatialData_Public202203','BasinMaster311_20220224.shp')
tfdd_raw <- read_sf(tfdd_fn)
tfdd <- st_transform(tfdd_raw,4326) %>%
  mutate(bid = row_number()) %>%
  dplyr::select(BCODE,Basin_Name,Continent_,Area_km2,bid)

tfdd_bid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::select(bid) %>%
  pull()

union_bid <- sort(unique(tfdd_bid))

##
## Any species in areas
##
master_tab_all_venn_GSA <- master_tab %>%
  dplyr::filter(!is.na(area)) %>%
  dplyr::filter(!is.na(pthreat)) %>%
  dplyr::filter(!is.na(d_endemic100)) %>%
  dplyr::select(species,d_endemic100,area,pthreat,basin_bids, entity_ids) %>%
  # Produce statistics for entire set of geographic areas (union) #
  distinct() %>%
  
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  
  # gid ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  
  # in basin OR country
  dplyr::filter(basin_bids %in% c(union_bid) | entity_ids %in% c(union_gid)) %>%
  
  # drop identifiers and keep distinct rows
  dplyr::select(-c(entity_ids,basin_bids)) %>%
  distinct() %>%
  
  # take largest area for species level
  #group_by(species) %>%
  #slice_max(area, n = 1, na_rm = TRUE) %>%
  #ungroup() %>%
  
  group_by(species,pthreat,d_endemic100) %>%
  dplyr::summarize(d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE),
                   area = max(area,na.rm=TRUE)) %>%
  ungroup() %>%
  
  dplyr::select(species,d_endemic100,area,pthreat) %>%
  
  distinct() %>%
  mutate(spp_smallocc50 = ifelse(area <= 50*50,species,NA),
         spp_tprob80 = ifelse(pthreat >= 80,species,NA),
         spp_endemic100 = ifelse(d_endemic100 == 1,species,NA)
  ) %>%
  dplyr::select(species, spp_smallocc50, spp_tprob80, spp_endemic100)

# Convert to logical (TRUE/FALSE)
master_tab_all_venn_GSA$A <- !is.na(master_tab_all_venn_GSA$spp_endemic100)
master_tab_all_venn_GSA$B <- !is.na(master_tab_all_venn_GSA$spp_smallocc50)   
master_tab_all_venn_GSA$C <- !is.na(master_tab_all_venn_GSA$spp_tprob80)

print(sprintf("Number of endemic (100) species  = %s",sum(master_tab_all_venn_GSA$A,na.rm = TRUE)))
print(sprintf("Number of species small occ 50x50 = %s",sum(master_tab_all_venn_GSA$B,na.rm = TRUE)))
print(sprintf("Number of species tprob80 = %s",sum(master_tab_all_venn_GSA$C,na.rm = TRUE)))

df_venn <- master_tab_all_venn_GSA %>%
  dplyr::select(A,B,C)


# Create a Venn diagram using ggVennDiagram
venn_data <- ggvenn(df_venn, show_percentage = FALSE)
# Extract the geometry of the Venn diagram
venn_polygons <- venn_data$data
# Assume the 'x' and 'y' columns represent the coordinates of the polygon
venn_pt <- st_as_sf(venn_polygons, coords = c("x", "y"), crs = 4326, agr = "constant")
# Create a LineString from the extracted coordinates
venn_sf <- st_sfc(st_linestring(st_coordinates(venn_pt))) %>%
  st_cast(.,"POLYGON") %>%
  st_union() %>%
  st_cast(.,"LINESTRING") %>%
  st_cast(.,"POLYGON") %>%
  st_make_valid() %>%
  st_convex_hull()

# Function to create ellipse coordinates
create_ellipse <- function(center = c(0, 0), radius = c(1, 0.5), angle = 0, npoints = 100) {
  # Generate the points for the ellipse
  theta <- seq(0, 2 * pi, length.out = npoints)
  x <- radius[1] * cos(theta)
  y <- radius[2] * sin(theta)
  
  # Rotation matrix to rotate the ellipse points
  angle_rad <- angle * pi / 180  # Convert angle from degrees to radians
  x_rot <- x * cos(angle_rad) - y * sin(angle_rad)
  y_rot <- x * sin(angle_rad) + y * cos(angle_rad)
  
  # Translate the ellipse to the desired center
  x_rot <- x_rot + center[1]
  y_rot <- y_rot + center[2]
  
  return(data.frame(x = x_rot, y = y_rot))
}

st_udf_identity = function(x, y) st_difference(x, st_union(st_combine(y)))

##
## endemic
##
# Create ellipse coordinates (adjust center and radius as needed)
ellipse_endemic <- create_ellipse(center = c(-1, 1), 
                                  radius = c(1, 0.5), 
                                  angle = 45+90,
                                  npoints = 200)
ellipse_pt <- st_as_sf(ellipse_endemic, coords = c("x", "y"), crs = 4326, agr = "constant")
# Create a LineString from the extracted coordinates
ellipse_sf <- st_sfc(st_linestring(st_coordinates(ellipse_pt))) %>%
  st_cast(.,"POLYGON") %>% st_make_valid()
ellipse_endemic_ply <- st_udf_identity(ellipse_sf, venn_sf)
ellipse_endemic_pt <- ellipse_endemic_ply %>% st_as_sf() %>%
  st_cast("POINT") %>%
  st_as_sf()
ellipse_endemic_clip <- st_set_geometry(ellipse_endemic_pt,"geometry") %>%
  dplyr::mutate(
    x = st_coordinates(.)[, 1],  # Extract and add x coordinate
    y = st_coordinates(.)[, 2]   # Extract and add y coordinate
  ) %>%
  st_set_crs(.,4326)
ellipse_endemic_clip_centroid <- st_centroid(ellipse_endemic_ply) %>%
  st_as_sf() %>% st_set_crs(.,4326) %>%
  dplyr::mutate(label = ellipse_endemic_value)


##
## small
##
# Create ellipse coordinates (adjust center and radius as needed)
ellipse_small <- create_ellipse(center = c(1, 1), 
                                  radius = c(1, 0.5), 
                                  angle = 45,
                                  npoints = 200)
ellipse_small_pt <- st_as_sf(ellipse_small, coords = c("x", "y"), crs = 4326, agr = "constant")
# Create a LineString from the extracted coordinates
ellipse_small_sf <- st_sfc(st_linestring(st_coordinates(ellipse_small_pt))) %>%
  st_cast(.,"POLYGON") %>% st_make_valid()
ellipse_small_ply <- st_udf_identity(ellipse_small_sf, venn_sf)
ellipse_small_pt <- ellipse_small_ply %>% st_as_sf() %>%
  st_cast("POINT") %>%
  st_as_sf()
ellipse_small_clip <- st_set_geometry(ellipse_small_pt,"geometry") %>%
  dplyr::mutate(
    x = st_coordinates(.)[, 1],  # Extract and add x coordinate
    y = st_coordinates(.)[, 2]   # Extract and add y coordinate
  ) %>%
  st_set_crs(.,4326)
ellipse_small_clip_centroid <- st_centroid(ellipse_small_ply) %>%
  st_as_sf() %>% st_set_crs(.,4326) %>%
  dplyr::mutate(label = ellipse_small_value)

# force x,y 
coords <- st_coordinates(ellipse_small_clip_centroid)
# Modify the coordinates directly (for example, new coordinates)
coords[1, ] <- c(1.480839, 1.480839)
# Create the updated geometry with the modified coordinates
st_geometry(ellipse_small_clip_centroid) <- st_sfc(st_point(coords[1, ]), crs = 4326)


##
## ETI
##
# Create ellipse coordinates (adjust center and radius as needed)
ellipse_eti <- create_ellipse(center = c(0, -1), 
                                radius = c(1, 0.5), 
                                angle = 90,
                                npoints = 200)
ellipse_eti_pt <- st_as_sf(ellipse_eti, coords = c("x", "y"), crs = 4326, agr = "constant")
# Create a LineString from the extracted coordinates
ellipse_eti_sf <- st_sfc(st_linestring(st_coordinates(ellipse_eti_pt))) %>%
  st_cast(.,"POLYGON") %>% st_make_valid()
ellipse_eti_ply <- st_udf_identity(ellipse_eti_sf, venn_sf)
ellipse_eti_pt <- ellipse_eti_ply %>% st_as_sf() %>%
  st_cast("POINT") %>%
  st_as_sf()
ellipse_eti_clip <- st_set_geometry(ellipse_eti_pt,"geometry") %>%
  dplyr::mutate(
    x = st_coordinates(.)[, 1],  # Extract and add x coordinate
    y = st_coordinates(.)[, 2]   # Extract and add y coordinate
  ) %>%
  st_set_crs(.,4326)
ellipse_eti_clip_centroid <- st_centroid(ellipse_eti_ply) %>%
  st_as_sf() %>% st_set_crs(.,4326) %>%
  dplyr::mutate(label = ellipse_eti_value)

centroids_dt <- data.table::rbindlist(list(ellipse_endemic_clip_centroid,
                                           ellipse_small_clip_centroid,
                                           ellipse_eti_clip_centroid))
centroids_sf <- centroids_dt %>% st_as_sf()

# Define the alpha value (transparency)
# Function to calculate new hex color with alpha transparency
calculate_hex_with_alpha <- function(hex_color, alpha) {
  # Convert hex to RGB
  rgb_values <- col2rgb(hex_color)
  
  # Convert alpha to range 0-255 (transparency)
  alpha_value <- round(alpha * 255)
  
  # Convert RGB values to hex and combine with alpha
  hex_color_with_alpha <- sprintf("#%02X%02X%02X%02X",
                                  rgb_values[1],
                                  rgb_values[2],
                                  rgb_values[3],
                                  alpha_value)
  
  return(hex_color_with_alpha)
}

# Calculate the new color with alpha
new_color1 <- calculate_hex_with_alpha("#33CCCC", 0.1)
new_color2 <- calculate_hex_with_alpha("#F1CC4F", 0.1)
new_color3 <- calculate_hex_with_alpha("#FDA6A6", 0.1)

# Plot the Venn diagram
p6 <- ggplot() +
  geom_polygon(data = ellipse_endemic_clip, aes(x = x, y = y), 
               fill = "#33CCCC", alpha = 0.1, color = NA, size = 1) +  # Ellipse layer
  geom_polygon(data = ellipse_small_clip, aes(x = x, y = y), 
               fill = "#F1CC4F", alpha = 0.1, color = NA, size = 1) +  # Ellipse layer
  geom_polygon(data = ellipse_eti_clip, aes(x = x, y = y), 
               fill = "#FDA6A6", alpha = 0.1, color = NA, size = 1) +  # Ellipse layer
  ggnewscale::new_scale_fill() +
  # fill in white background
  geom_polygon(data=venn_pt,aes(x=x_raw,y=y_raw),fill='white',color=NA) + 
  geom_venn(data=df_venn, aes(A = A, B = B, C = C),
            set_names = "",
            fill_color = c("#33CCCC", "#F1CC4F", "#FDA6A6"), # Customize colors for each circle
            fill_alpha = 0.5,
            stroke_color = NA,
            stroke_size = 0,
            show_outside = c("none"),
            text_size = 4,
            #set_name_color='white',
              show_percentage = FALSE) +
  labs(fill = NULL) +  
  geom_sf_label(data = centroids_sf, aes(label = label), size = 4, color = "black", 
                fill = NA, fontface = "italic", label.size =0,
                show.legend = FALSE) +
  ggnewscale::new_scale_color() +
  geom_point(aes(x=5,y=5,color = "A"),
             size = 4,
             show.legend = TRUE) +  # Blank data layer for legend entry
  geom_point(aes(x=5,y=5,color = "B"),
             size = 4,
             show.legend = TRUE) +  # Blank data layer for legend entry
  geom_point(aes(x=5,y=5,color = "C"),
             size = 4,
             show.legend = TRUE) +  # Blank data layer for legend entry
  geom_point(aes(x=5,y=5,color = "D"),
             size = 4,
             show.legend = TRUE) +  # Blank data layer for legend entry
  geom_point(aes(x=5,y=5,color = "E"),
             size = 4,
             show.legend = TRUE) +  # Blank data layer for legend entry
  geom_point(aes(x=5,y=5,color = "F"),
             size = 4,
             show.legend = TRUE) +  # Blank data layer for legend entry
  scale_color_manual(
    values = c("A" = "#33CCCC", "B"= new_color1, "C" = "#F1CC4F",
               "D" = new_color2, "E"= "#FDA6A6", "F" = new_color3
               ),  # Colors for the stages
    labels = c("Endemic - GSOA", 
               "Endemic - Other", 
               "Small Occurrence Region - GSOA",
               "Small Occurrence Region - Other", 
               "Extinction Threat Indicator - GSOA", 
               "Extinction Threat Indicator - Other")
  ) + 
  coord_fixed(xlim = c(-2,2), ylim =  c(-2,2), expand = FALSE) +
  guides(fill = guide_legend(title = 'Title')) +
  theme(
    legend.position = "right",  # Position legend to the right
    legend.title = element_blank(),  # Optionally remove legend title
    legend.key.size = unit(1, "lines"),  # Adjust size of legend keys (optional)
    legend.text = element_text(size = 12),
    legend.spacing.x = unit(1, "lines"),
    legend.spacing.y = unit(1, "cm"),  # Increase vertical space between legend items
    panel.grid = element_blank(),
    panel.background = element_rect(fill = "white"),
    plot.background = element_rect(fill = "white"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_blank(),
    axis.text.y = element_blank(),
    axis.ticks = element_blank()  # Remove axis ticks
  )

p6

ggsave(p6_fn, p6, width = 6, height = 3.5)
