####################################################################
##
## boundary file : countries, non determined legal status and coastline
##
####################################################################


# download continent codes 
x <- httr::GET("https://gist.github.com/stevewithington/20a69c0b6d2ff846ea5d35e5fc47f26c/archive/13716ceb2f22b5643ce5e7039643c86a0e0c6da6.zip")

# Save to file
bin <- content(x, "raw")
tdir <- tempdir()
writeBin(bin, file.path(tdir,'country-and-continent-codes.zip'))
unzip(file.path(tdir,'country-and-continent-codes.zip'), exdir = tdir)
csv_fn <- list.files(tdir,pattern='.csv',full.names = T, recursive = T)
cntctr <- readr::read_csv(csv_fn) %>%
  dplyr::rename(Continent = Continent_Name,
                ISO_A3 = Three_Letter_Country_Code,
                ISO_A2 = Two_Letter_Country_Code) %>%
  dplyr::select(-c(Country_Number,Country_Name))

cntctr$ISO_A3[is.na(cntctr$ISO_A3)] <- "NAN"
cntctr$ISO_A3[cntctr$ISO_A3=="PSE"] <- "PSX"


##
bnd_dir <- file.path(wkdir,'local_data','geo_data')

bnd_ctr_ply <- st_read(file.path(bnd_dir,'ne_10m_WB2019_admin_0_countries.shp'))
bnd_dsp_ply <- st_read(file.path(bnd_dir,'ne_10m_WB2019_admin_0_disputed.shp'))
# bind together
bnd_dtp <- data.table::rbindlist(list(bnd_ctr_ply,bnd_dsp_ply),fill=TRUE)
# back to sf
bndp <- st_sf(bnd_dtp)
# make valid
bnd_ply <- bndp %>% st_make_valid()
bnd_ply_wbreg <- bnd_ply %>% dplyr::select(WB_REGION)

# Define the bounding box coordinates (xmin, ymin, xmax, ymax)
xmin <- -179
ymin <- -60
xmax <- 179
ymax <- 85

# Create a polygon representing the bounding box
bbox_polygon <- st_sfc(st_polygon(list(matrix(c(xmin, ymin, xmax, ymin, xmax, ymax, xmin, ymax, xmin, ymin), ncol = 2, byrow = TRUE))))

# Assign a CRS to the polygon (for example, EPSG:4326)
st_crs(bbox_polygon) <- 4326

# Convert the polygon into an sf object
bnd_ply_bbox <- st_sf(geometry = bbox_polygon)
bnd_ply_map <- st_crop(bnd_ply, bnd_ply_bbox) %>% st_cast(.,'MULTIPOLYGON')

bnd_ply_new <- st_read(file.path(wkdir,'local_data','geo_data','WB_GAD_Disputes.shp'))

bnd_ply_ilemi_triangle <- bnd_ply_new %>%
  dplyr::filter(nam_0 == 'Wait - KEN/SSD')

##
## WB land-eez
##
bnd_fn <- file.path(wkdir,'local_data','geo_data',sprintf('World_Bank_Countries_Disputed_merged_EEZ_land_and_ocean%s.shp',admin_vers))
bnd <- sf::read_sf(bnd_fn)

# Perform the spatial join to find overlaps
overlap <- st_join(bnd, bnd_ply_wbreg, join = st_intersects, left = TRUE)

# Calculate the area of the intersection
overlap <- overlap %>%
  mutate(intersection_area = st_area(geometry)) %>%
  filter(!is.na(intersection_area))

# Retain only the largest area overlap for each polygon in poly1
largest_overlap <- overlap %>%
  group_by(gid) %>%  # Replace with your unique identifier for poly1 if available
  dplyr::slice(which.max(intersection_area)) %>%
  ungroup()

# Select the relevant attributes from poly2
result <- largest_overlap %>% dplyr::select(-intersection_area) %>% st_drop_geometry()
table(result$WB_REGION)
table(result$bndtype)
#result[is.na(result$WB_REGION)&result$bndtype=="countries","gid"]

# replace disputed joint
result$WB_REGION[result$bndtype=="disputed"] <- "disputed"
result$WB_REGION[result$bndtype=="joint"] <- "joint"
result$WB_REGION[result$bndtype=="ocean"] <- "ocean"
result$WB_REGION[result$bndtype=="Antarctica"] <- "Antarctica"
wbreg <- result %>% dplyr::select(gid,WB_REGION)

# add World Bank region
bnd <- merge(bnd,wbreg,by='gid',all.x=TRUE)

# add continent
bndp <- merge(bnd,cntctr,by.y="ISO_A3",by.x='ISO_A3',all.x=TRUE)

table(bndp$Continent_Code)
table(bndp$WB_REGION)
is.na(bndp$WB_REGION)

bndp$Continent[bndp$ISO_A3=="KOS"] <- 'Europe'
bndp$Continent_Code[bndp$ISO_A3=="KOS"] <- 'EU'

bndp$Continent[bndp$WB_ISO=="CXR"] <- 'Asia'
bndp$Continent_Code[bndp$WB_ISO=="CXR"] <- 'AS'
bndp$Continent[bndp$WB_ISO=="CCK"] <- 'Asia'
bndp$Continent_Code[bndp$ISO_A3=="CCK"] <- 'AS'
bndp$Continent[bndp$WB_ISO=="CLP"] <- 'Asia'
bndp$Continent_Code[bndp$WB_ISO=="CLP"] <- 'AS'

bndp$Continent[bndp$bndtype=="ocean"] <- 'Ocean'

table(bndp$Continent)
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Argentina / Uruguay'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Argentina / Uruguay'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Australia / East Timor'] <- 'Oceania'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Australia / East Timor'] <- 'EAP / Other'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Colombia / Dominican Republic'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Colombia / Dominican Republic'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Colombia / Jamaica'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Colombia / Jamaica'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Costa Rica / Ecuador (Galapagos)'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Costa Rica / Ecuador (Galapagos)'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Ecuador / Colombia'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Ecuador / Colombia'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Ecuador / Peru'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Ecuador / Peru'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Guyana / Barbados'] <- 'North America'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Guyana / Barbados'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Honduras / Cayman Islands'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Honduras / Cayman Islands'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Iceland / Denmark (Faeroe Islands)'] <- 'Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Iceland / Denmark (Faeroe Islands)'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Iceland / Norway (Jan Mayen)'] <- 'Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Iceland / Norway (Jan Mayen)'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Italy / France'] <- 'Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Italy / France'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Japan / Korea'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Japan / Korea'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Nigeria / Sao Tome and Principe'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Nigeria / Sao Tome and Principe'] <- 'AFR'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Spain / France'] <- 'Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Spain / France'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area Sweden / Norway'] <- 'Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area Sweden / Norway'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area United Kingdom / Denmark (Faeroe Islands)'] <- 'Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area United Kingdom / Denmark (Faeroe Islands)'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Joint regime area United States / Russia'] <- 'North America / Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Joint regime area United States / Russia'] <- 'EAP / Other'


#
bndp$Continent[bndp$WB_DATANAM=='Disputed area Alhucemas Islands: Spain / Morocco'] <- 'Africa / Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Alhucemas Islands: Spain / Morocco'] <- 'MNA / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Chafarinas Islands: Spain / Morocco'] <- 'Africa / Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Chafarinas Islands: Spain / Morocco'] <- 'MNA / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Chagos Archipelago Exclusive Economic Zone: UK / Mauritius'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Chagos Archipelago Exclusive Economic Zone: UK / Mauritius'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Doumeira Islands: Djibouti / Eritrea'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Doumeira Islands: Djibouti / Eritrea'] <- 'AFR / MNA'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Falkland Islands Exclusive Economic Zone: UK / Argentina'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Falkland Islands Exclusive Economic Zone: UK / Argentina'] <- 'LAC / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Gibraltarian Exclusive Economic Zone'] <- 'Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Gibraltarian Exclusive Economic Zone'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Glorioso Islands: France / Madagascar'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Glorioso Islands: France / Madagascar'] <- 'AFR / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Ile Tromelin: Reunion / Mauritus'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Ile Tromelin: Reunion / Mauritus'] <- 'AFR'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Kuril Islands: Japan / Russia'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Kuril Islands: Japan / Russia'] <- 'EAP / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Liancourt Rocks: Japan / South Korea'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Liancourt Rocks: Japan / South Korea'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Matthew and Hunter Islands: New Caledonia / Vanuatu'] <- 'Oceania'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Matthew and Hunter Islands: New Caledonia / Vanuatu'] <- 'EAP'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Mayotte: France / Comoros'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Mayotte: France / Comoros'] <- 'AFR / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Melilla: Spain / Morocco'] <- 'Africa / Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Melilla: Spain / Morocco'] <- 'AFR / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Navassa Island: USA / Haiti / Jamaica'] <- 'North America'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Navassa Island: USA / Haiti / Jamaica'] <- 'LAC / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Senkaku Islands: Japan / China / Taiwan'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Senkaku Islands: Japan / China / Taiwan'] <- 'EAP / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area South China Sea'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area South China Sea'] <- 'EAP / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area South Georgia and South Sandwich Exclusive Economic Zone: UK / Argentina'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area South Georgia and South Sandwich Exclusive Economic Zone: UK / Argentina'] <- 'LAC / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Ukrainian Exclusive Economic Zone'] <- 'Europe'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Ukrainian Exclusive Economic Zone'] <- 'ECA / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area Western Saharan Exclusive Economic Zone'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area Western Saharan Exclusive Economic Zone'] <- 'MNA'
bndp$Continent[bndp$WB_DATANAM=='Disputed area: Canada / USA'] <- 'North America'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area: Canada / USA'] <- 'Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area: Iran / United Arab Emirates'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area: Iran / United Arab Emirates'] <- 'MNA / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area: Kenya / Somalia'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area: Kenya / Somalia'] <- 'AFR'
bndp$Continent[bndp$WB_DATANAM=='Disputed area: Palestinian Exclusive Economic Zone'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area: Palestinian Exclusive Economic Zone'] <- 'MNA'
bndp$Continent[bndp$WB_DATANAM=='Disputed area: Puerto Rico / Dominican Republic'] <- 'North America'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area: Puerto Rico / Dominican Republic'] <- 'LAC / Other'
bndp$Continent[bndp$WB_DATANAM=='Disputed area: Sudan / Egypt'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area: Sudan / Egypt'] <- 'AFR / MNA'
bndp$Continent[bndp$WB_DATANAM=='Disputed area: Trinidad and Tobago / Venezuela / Guyana'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area: Trinidad and Tobago / Venezuela / Guyana'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Disputed area: Venezuela / Aruba / Dominican Republic'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area: Venezuela / Aruba / Dominican Republic'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Disputed area: Venezuela / Colombia / Dominican Republic'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area: Venezuela / Colombia / Dominican Republic'] <- 'LAC'

#
bndp$Continent[bndp$WB_DATANAM=='Disputed area: Venezuela / Colombia / Dominican Republic'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Disputed area: Venezuela / Colombia / Dominican Republic'] <- 'LAC'
bndp$Continent[bndp$WB_DATANAM=='Abyei'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Abyei'] <- 'AFR'
bndp$Continent[bndp$WB_DATANAM=='Aksai Chin'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Aksai Chin'] <- 'SOA / EAP'
bndp$Continent[bndp$WB_DATANAM=='Arunachal Pradesh'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Arunachal Pradesh'] <- 'SOA / EAP'
bndp$Continent[bndp$WB_DATANAM=='Demchok'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Demchok'] <- 'SOA / EAP'
bndp$Continent[bndp$WB_DATANAM=='Falkland Islands (UK)/Islas Malvinas'] <- 'South America'
bndp$WB_REGION[bndp$WB_DATANAM=='Falkland Islands (UK)/Islas Malvinas'] <- 'LAC / Other'
bndp$Continent[bndp$WB_DATANAM=='Western Sahara'] <- 'Africa'
bndp$WB_REGION[bndp$WB_DATANAM=='Western Sahara'] <- 'MNA'
bndp$Continent[bndp$WB_DATANAM=='Kalapani'] <- 'Asia'
bndp$WB_REGION[bndp$WB_DATANAM=='Kalapani'] <- 'SOA / EAP'

bndp_df <- bndp %>% st_drop_geometry()

table(bndp_df$WB_REGION)
table(bndp_df$Continent)

# PROJ.4 string for Eckert IV projection
# eckertIV <- "+proj=eck4 +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs" 
bnddir <- file.path(wkdir,'local_data','geo_data','Boundary_Data_50mil')

bnd0ocean_fn <- file.path(bnddir,'ne_50m_WB_coastline.shp')
bnd0ocean <- read_sf(bnd0ocean_fn) %>%
  dplyr::mutate(bndtype = "ocean",
                colortype = "ocean")

##
## 2024-10-25 Modified for Ilemi triangle
##

# country level boundaries #
bnd_fn <- file.path(bnddir,'ne_50m_WB_admin_0_boundary_lines.shp')
bndctr <- read_sf(bnd_fn)  %>%
  dplyr::mutate(bndtype="countries",
                colortype="land")

# disputed boundaries
bnddisp_fn <- file.path(bnddir,'ne_50m_WB_admin_0_boundary_lines_disputed.shp')
bnddisp <- read_sf(bnddisp_fn) %>%
  dplyr::mutate(bndtype="disputed",
                colortype="land") %>%
  st_cast(.,"MULTILINESTRING")

# bind together
bnd_dtl <- data.table::rbindlist(list(bndctr,bnddisp,bnd0ocean),fill=TRUE)

# back to sf
bndl <- st_sf(bnd_dtl)

# make valid
bndline <- bndl %>% st_make_valid() %>% st_cast(.,"MULTILINESTRING")
bndline_map <- st_crop(bndline, bnd_ply_bbox) %>% st_cast(.,'MULTILINESTRING')

# Create a global bounding box (from -180 to 180 longitudes and -90 to 90 latitudes)
bbox <- st_sfc(st_polygon(list(matrix(c(-180, -90, 180, -90, 180, 90, -180, 90, -180, -90), 
                                      ncol = 2, byrow = TRUE))), crs = 4326)

# Use st_make_grid() to create a 5x5 degree grid
grid <- st_make_grid(bbox, cellsize = c(5, 5), what = "polygons")

# Convert to an sf object for easier manipulation
grid_sf <- st_sf(geometry = grid)
