##
## Table 1: Area, human population count (WorldPop) and total species in geopolitically sensitive and overlapping areas
##


print("requires input boundary polygon dataset")
print("requires pop dataset")

jointterr_version <- Sys.Date()
dispterr_version <- Sys.Date()
fcv_version <- Sys.Date()
tfddbasins_version <- Sys.Date()


##
pop_r_fn <- file.path(wkdir,'local_data','geo_data','pop', "ppp_2020_1km_Aggregated.tif")
print(sprintf("File exists : %s",file.exists(pop_r_fn)))

results <- list()

##
## Joint area polygon
##
print("bndp is loaded")
bndjoint <- bndp %>%
  dplyr::filter(bndtype=="joint") %>%
  dplyr::summarize(geometry = st_union(geometry)) %>%
  dplyr::mutate(area_km2 = round(as.numeric(st_area(.) / 1000000),1))
  
require(exactextractr)
bndjoint_df <- exactextractr::exact_extract(wpop20,bndjoint, 'sum') %>%
  as.data.frame() %>% mutate(across(.fns = ~replace(., . > 0 , 0))) %>% pull

jointterr_all_fn <- file.path(wkdir,'tables',sprintf("vers%s",jointterr_version),sprintf('joint_species_all_summary%s.dta',jointterr_version))
jointterr_all <- haven::read_dta(jointterr_all_fn)  %>%
  dplyr::filter(!(species_groups == "Terr. Vertebrates [Class]")) %>%
  dplyr::summarize(jointterr_all_n_spp_total = sum(n_spp_total,na.rm=TRUE))


results <- c('Marine joint areas',bndjoint_df,bndjoint$area_km2,jointterr_all$jointterr_all_n_spp_total)

##
## Disputed area polygon
##
print("bndp is loaded")
bnddisp <- bndp %>%
  dplyr::filter(bndtype=="disputed") %>%
  dplyr::summarize(geometry = st_union(geometry)) %>%
  dplyr::mutate(area_km2 = round(as.numeric(st_area(.) / 1000000),1))

require(exactextractr)
bnddisp_df <- exactextractr::exact_extract(wpop20,bnddisp, 'sum')


dispterr_all_dta_fn <- file.path(wkdir,'tables',sprintf("vers%s",dispterr_version),sprintf('disputed_species_all_summary%s.dta',dispterr_version))
dispterr_all <- haven::read_dta(dispterr_all_dta_fn) %>%
  dplyr::summarize(dispterr_all_n_spp_total = sum(n_spp_total,na.rm=TRUE))

results <- rbind(results,c('Disputed areas',bnddisp_df,bnddisp$area_km2, dispterr_all$dispterr_all_n_spp_total))

##
## FCS
##

fcv_entity_fn <- file.path(localdir,'tab_data','fcv.xlsx')
fcv_entity <- readxl::read_excel(fcv_entity_fn) %>%
  dplyr::rename(WB_ISO = WB_IS0)

fcv_entity_gid <- fcv_entity %>%
  dplyr::select(gid) %>%
  pull()

bndfcv <- bndp %>%
  dplyr::filter(gid %in% fcv_entity_gid) %>%
  dplyr::summarize(geometry = st_union(geometry)) %>%
  dplyr::mutate(area_km2 = round(as.numeric(st_area(.) / 1000000),1))

require(exactextractr)
bndfcv_df <- exactextractr::exact_extract(wpop20,bndfcv, 'sum')


master_tab_fcv_all_fn <- file.path(wkdir,'tables',sprintf("vers%s",fcv_version),sprintf('fcv_species_all_summary%s.dta',fcv_version))
master_tab_fcv_all <- haven::read_dta(master_tab_fcv_all_fn) %>%
  dplyr::summarize(fcv_all_n_spp_total = sum(n_spp_total,na.rm=TRUE))

results <- rbind(results,c('FCV',bndfcv_df,bndfcv$area_km2,master_tab_fcv_all$fcv_all_n_spp_total))

##
## River basins
##

## basins
tfdd_fn <- file.path(localdir,'geo_data','TFDD_SpatialData_Public202203','BasinMaster311_20220224.shp')
tfdd_raw <- read_sf(tfdd_fn)
tfdd_geo <- st_transform(tfdd_raw,4326)
sum(tfdd_geo$Area_km2,na.rm=TRUE)

tfdd_all <- tfdd_geo %>%
  dplyr::summarize(geometry = st_union(geometry)) %>%
  dplyr::mutate(area_km2 = round(as.numeric(st_area(.) / 1000000),1))
sum(tfdd_all$area_km2)

require(exactextractr)
tfdd_df <- exactextractr::exact_extract(wpop20,tfdd_all, 'sum')

tfddbasins_all_dta_fn <- file.path(wkdir,'tables',sprintf("vers%s",tfddbasins_version),sprintf('tfddbasins_species_all_summary%s.dta',tfddbasins_version))
tfddbasins_all <- haven::read_dta(tfddbasins_all_dta_fn)  %>%
  dplyr::summarize(tfddbasins_all_n_spp_total = sum(n_spp_total,na.rm=TRUE))


results <- rbind(results,c('Basins',tfdd_df,tfdd_all$area_km2,tfddbasins_all$tfddbasins_all_n_spp_total))

## table 
df <- as.data.frame(results,row.names=F)
colnames(df)<- c('group','Population','Area','Total_Species')
df$Population <- round(as.numeric(df$Population),0)
df$Area <- round(as.numeric(df$Area),0)
df$Total_Species <- round(as.numeric(df$Total_Species),0)

# Define the custom order for 'Group' column
custom_order <- c("Disputed areas", "FCV", "Marine joint areas", "Basins")

# Convert 'Group' to a factor with the specified order
df$group <- factor(df$group, levels = custom_order)

# Reorder the rows based on the custom factor order
df <- df[order(df$group), ]
df <- df %>% dplyr::select(group,Area,Population,Total_Species)

#Count of Total Species (Presence)	
#Count of Endemic Species	
#Count of Species with Small Occurrence Region	
#Count of Species with Threats of Extinction more than 80%

df_fn <- file.path(tbldir,sprintf('Tbl01_sensitive_groups_pop_and_area_and_total_species%s.csv',Sys.Date()))
write.csv(df,df_fn,row.names=F)

attr(df$Area,'label') <- 'Area (km2)'
attr(df$Population,'label') <- 'Population'
attr(df$Total_Species,'label') <- 'Total species'
attr(df$group,'label') <- 'Group'

out_all_fn <- file.path(tbldir,sprintf('Tbl01_sensitive_groups_pop_and_area_and_total_species%s.dta',Sys.Date()))
haven::write_dta(df,out_all_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(df),
  Label = sapply(df, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,
              sprintf('Tbl01_sensitive_groups_pop_and_area_and_total_species_labels_%s.csv',Sys.Date())), 
              row.names = FALSE)

