##
## Table 2:  Species richness and count of critical species by geopolitically sensitive and overlapping areas
##

print("requires input boundary polygon dataset")
print("requires pop dataset")

jointterr_version <- Sys.Date()
dispterr_version <- Sys.Date()
fcv_version <- Sys.Date()
tfddbasins_version <- Sys.Date()

##
results <- list()

##
## Joint area polygon
##
print("bndp is loaded")
jointterr_all_fn <- file.path(wkdir,'tables',sprintf("vers%s",jointterr_version),sprintf('joint_species_all_summary%s.dta',jointterr_version))
jointterr_all <- haven::read_dta(jointterr_all_fn) %>%
  dplyr::filter(!(species_groups == "Terr. Vertebrates [Class]")) %>%
  dplyr::summarize(n_spp_total = sum(n_spp_total,na.rm=TRUE),
                   n_spp_end100 = sum(n_spp_end100, na.rm=TRUE),
                   n_spp_small50 = sum(n_spp_small50,na.rm=TRUE),
                   n_spp_tprob80  = sum(n_spp_tprob80,na.rm=TRUE)
                   ) %>%
  dplyr::mutate(geog = 'Marine Joint Regimes') %>%
  relocate(geog, .before = 1)

results <- as.data.frame(jointterr_all)
             

##
## Disputed area polygon
##
dispterr_all_dta_fn <- file.path(wkdir,'tables',sprintf("vers%s",dispterr_version),sprintf('disputed_species_all_summary%s.dta',dispterr_version))
dispterr_all <- haven::read_dta(dispterr_all_dta_fn) %>%
  dplyr::summarize(n_spp_total = sum(n_spp_total,na.rm=TRUE),
                   n_spp_end100 = sum(n_spp_end100, na.rm=TRUE),
                   n_spp_small50 = sum(n_spp_small50,na.rm=TRUE),
                   n_spp_tprob80  = sum(n_spp_tprob80,na.rm=TRUE)
  ) %>%
  dplyr::mutate(geog = 'Non-determined legal status Territories') %>%
  relocate(geog, .before = 1)

results <- rbind(results,dispterr_all)

##
## FCS
##

master_tab_fcv_all_fn <- file.path(wkdir,'tables',sprintf("vers%s",fcv_version),sprintf('fcv_species_all_summary%s.dta',fcv_version))
master_tab_fcv_all <- haven::read_dta(master_tab_fcv_all_fn) %>%
  dplyr::summarize(n_spp_total = sum(n_spp_total,na.rm=TRUE),
                   n_spp_end100 = sum(n_spp_end100, na.rm=TRUE),
                   n_spp_small50 = sum(n_spp_small50,na.rm=TRUE),
                   n_spp_tprob80  = sum(n_spp_tprob80,na.rm=TRUE)
  ) %>%
  dplyr::mutate(geog = 'Fragile and Conflict-Affected Situations') %>%
  relocate(geog, .before = 1)

results <- rbind(results,master_tab_fcv_all)

##
## River basins
##

## basins
tfddbasins_all_dta_fn <- file.path(wkdir,'tables',sprintf("vers%s",tfddbasins_version),sprintf('tfddbasins_species_all_summary%s.dta',tfddbasins_version))
tfddbasins_all <- haven::read_dta(tfddbasins_all_dta_fn)  %>%
  dplyr::summarize(n_spp_total = sum(n_spp_total,na.rm=TRUE),
                   n_spp_end100 = sum(n_spp_end100, na.rm=TRUE),
                   n_spp_small50 = sum(n_spp_small50,na.rm=TRUE),
                   n_spp_tprob80  = sum(n_spp_tprob80,na.rm=TRUE)
  ) %>%
  dplyr::mutate(geog = 'Transboundary River Basins') %>%
  relocate(geog, .before = 1)

results <- rbind(results,tfddbasins_all)

## table : Species richness and count of critical species
df <- as.data.frame(results)
colnames(df) <- c('group',
                 'Count of Total Species (Presence)',
                 'Count of Endemic Species',
                 'Count of Species with Small Occurrence Region',
                 'Count of Species with Threats of Extinction more than 80%'
                 )
# Define the custom order for 'Group' column
custom_order <- c("Non-determined legal status Territories", 
                  "Fragile and Conflict-Affected Situations", 
                  "Marine Joint Regimes", 
                  "Transboundary River Basins")

# Convert 'Group' to a factor with the specified order
df$group <- factor(df$group, levels = custom_order)

# Reorder the rows based on the custom factor order
df <- df[order(df$group), ]

df_fn <- file.path(tbldir,sprintf('Tbl02_groups_species_counts%s.csv',Sys.Date()))
write.csv(df,df_fn,row.names=F)

# for stata
df <- as.data.frame(results) %>% rename(group = geog)
# Define the custom order for 'Group' column
custom_order <- c("Non-determined legal status Territories", 
                  "Fragile and Conflict-Affected Situations", 
                  "Marine Joint Regimes", 
                  "Transboundary River Basins")

# Convert 'Group' to a factor with the specified order
df$group <- factor(df$group, levels = custom_order)

# Reorder the rows based on the custom factor order
df <- df[order(df$group), ]

attr(df$n_spp_total,'label') <- 'Count of Total Species (Presence) : Authors'
attr(df$n_spp_end100,'label') <- 'Count of Endemic Species (100) : Authors'
attr(df$n_spp_small50,'label') <- 'Count of Species with Small Occurrence Region (50x50) : Authors'
attr(df$n_spp_tprob80,'label') <- 'Count of Species with Threats of Extinction more than 80% : Authors'
attr(df$group,'label') <- 'Group'

out_all_fn <- file.path(tbldir,sprintf('Tbl02_groups_species_counts%s.dta',Sys.Date()))
haven::write_dta(df,out_all_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(df),
  Label = sapply(df, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,
                                  sprintf('Tbl02_groups_species_counts_labels_%s.csv',Sys.Date())), 
          row.names = FALSE)
