##
## Table 3: Transboundary river basins:  species covered by treaties and river basin organizations  
##

print("requires input boundary polygon dataset")
print("requires pop dataset")

tfddbasins_version <- Sys.Date()

##
results <- list()

## basins - all species
tfddbasins_all_dta_fn <- file.path(wkdir,'tables',sprintf("vers%s",tfddbasins_version),sprintf('tfddbasins_species_all_summary%s.dta',tfddbasins_version))
tfddbasins_all <- haven::read_dta(tfddbasins_all_dta_fn)  %>%
  dplyr::summarize(n_spp_total = sum(n_spp_total,na.rm=TRUE),
                   n_spp_end100 = sum(n_spp_end100, na.rm=TRUE),
                   n_spp_small50 = sum(n_spp_small50,na.rm=TRUE),
                   n_spp_tprob80  = sum(n_spp_tprob80,na.rm=TRUE),
                   n_spp_Endemic100xTprob80 = sum(n_spp_Endemic100xTprob80,na.rm=TRUE),
                   n_spp_small50xEndemic100 = sum(n_spp_small50xEndemic100,na.rm=TRUE),
                   n_spp_small50xTprob80 = sum(n_spp_small50xTprob80,na.rm=TRUE),
                   n_spp_small50xEndemic100xTprob80 = sum(n_spp_small50xEndemic100xTprob80,na.rm=TRUE)
  ) %>%
  dplyr::mutate(geog = 'Transboundary River Basins') %>%
  relocate(geog, .before = 1)

## basins by treaty
tfddbasins_by_treaty_dta_fn <- file.path(wkdir,'tables',sprintf("vers%s",tfddbasins_version),
                                   sprintf('tfddbasins_no_treaty_species_summary%s.dta',tfddbasins_version))
tfddbasins_by_treaty <- haven::read_dta(tfddbasins_by_treaty_dta_fn)  %>%
  # filter no treaty
  dplyr::filter(d_treaty == 0) %>%
  dplyr::mutate(geog = 'Without Treaty') %>%
  dplyr::select(-c(d_treaty)) %>%
  relocate(geog, .before = 1)


## basins by rbo
tfddbasins_by_rbo_dta_fn <- file.path(wkdir,'tables',sprintf("vers%s",tfddbasins_version),
                                         sprintf('tfddbasins_no_rbo_species_summary%s.dta',tfddbasins_version))
tfddbasins_by_rbo <- haven::read_dta(tfddbasins_by_rbo_dta_fn)  %>%
  # filter no rbo
  dplyr::filter(d_RBO == 0) %>%
  dplyr::mutate(geog = 'Without RBO') %>%
  dplyr::select(-c(d_RBO)) %>%
  relocate(geog, .before = 1)


## basins by rbo
tfddbasins_by_rbo_and_treaty_dta_fn <- file.path(wkdir,'tables',sprintf("vers%s",tfddbasins_version),
                                      sprintf('tfddbasins_no_rbo_and_treaty_species_summary%s.dta',tfddbasins_version))
tfddbasins_by_rbo_and_treaty <- haven::read_dta(tfddbasins_by_rbo_and_treaty_dta_fn)  %>%
  # filter no rbo AND treaty
  dplyr::filter(d_no_RBO_and_treaty == 1) %>%
  dplyr::mutate(geog = 'Without RBO and Treaty') %>%
  dplyr::select(-c(d_no_RBO_and_treaty)) %>%
  relocate(geog, .before = 1)



results <- data.table::rbindlist(list(tfddbasins_all,
                                      tfddbasins_by_treaty,
                                      tfddbasins_by_rbo,
                                      tfddbasins_by_rbo_and_treaty),fill=TRUE)
df <- results %>% as.data.frame()

# Pivot from wide to long
df_long <- df %>%
  pivot_longer(
    cols = starts_with("n_spp"),  # Select all columns starting with "n_spp"
    names_to = "species_type",     # Create a new column to hold the variable names (e.g., n_spp_total)
    values_to = "count"            # Create a new column to hold the values (counts)
  )

# Now, pivot it back from long to wide
df_wide <- df_long %>%
  pivot_wider(
    names_from = geog,  # This is the column whose values will become column names
    values_from = count         # This is the column with the actual data values
  )

df_wide2 <- df_wide %>%
  dplyr::mutate(`% Without Treaty` = round(`Without Treaty` / `Transboundary River Basins` * 100,2),
                `% Without RBO` = round(`Without RBO` / `Transboundary River Basins` * 100,2),
                `% Without RBO or Treaty` = round(`Without RBO and Treaty` / `Transboundary River Basins` * 100,2))

## table : Species richness and count of critical species
df <- df_wide2 %>%
  dplyr::mutate(
    species_type = case_when(
      species_type == "n_spp_total" ~ 'Species presence',
      species_type == "n_spp_end100" ~ 'Endemic',
      species_type == "n_spp_small50" ~ 'Small Occurrence Region',  
      species_type == "n_spp_tprob80" ~ 'Extinction Threat Indicator (ETI) > 80',
      species_type == "n_spp_small50xEndemic100" ~ 'Endemic with Small Occurrence Region',
      species_type == "n_spp_Endemic100xTprob80" ~ 'Endemic with ETI > 80',
      species_type == "n_spp_small50xTprob80" ~ 'Small Occurrence Region with ETI > 80',  
      species_type == "n_spp_small50xEndemic100xTprob80" ~ 'Endemic, Small Occurrence Region with ETI>80', 
      
      TRUE ~ species_type  
    )
  )

# Define the custom order for 'Group' column
custom_spp_type_order <- c("Species presence", 
                  "Endemic", 
                  "Small Occurrence Region", 
                  "Extinction Threat Indicator (ETI) > 80",
                  "Endemic with Small Occurrence Region",
                  "Small Occurrence Region with ETI > 80",
                  "Endemic with ETI > 80",
                  "Endemic, Small Occurrence Region with ETI>80")

# Convert 'Group' to a factor with the specified order
df$f_species_type <- factor(df$species_type, levels = custom_spp_type_order)
levels(df$f_species_type)

# Reorder the rows based on the custom factor order
df2 <- df %>% arrange(f_species_type) %>%
  dplyr::rename(`Total Species` = `Transboundary River Basins`) %>%
  dplyr::select(species_type,`Total Species`,
                `% Without Treaty`, `% Without RBO`,
                `% Without RBO or Treaty`)

df_fn <- file.path(tbldir,sprintf('Tbl03_species_by_treaties_and_RBO_%s.csv',Sys.Date()))
write.csv(df2,df_fn,row.names=F)

para1 <- sprintf("For species in critical categories (endemic, small range or high extinction threat indicator (ETI), between %1.1f%% and %1.1f%% are in basins that are not covered by international treaties, and between %1.1f%% and %1.1f%% are in basins not managed by RBOs. Between %1.1f%% and %1.1f%% are in basins not covered by treaties or RBOs.", 
                     min(df2$`% Without Treaty`),
                     max(df2$`% Without Treaty`),
                     min(df2$`% Without RBO`),
                     max(df2$`% Without RBO`),
                     min(df2$`% Without RBO or Treaty`),
                     max(df2$`% Without RBO or Treaty`)
                     )
para2 <- sprintf("This lack of governance coverage is especially troubling for endemic species with small occurrence regions (%1.2f%% without treaties; %1.2f%% without RBOs; %1.2f%% with neither) and high ETIs (%1.2f%% without treaties, %1.2f%% without RBOs; %1.2f%% with neither).",
                     df2[df2$species_type=="Endemic with Small Occurrence Region",]$`% Without Treaty`,
                     df2[df2$species_type=="Endemic with Small Occurrence Region",]$`% Without RBO`,
                     df2[df2$species_type=="Endemic with Small Occurrence Region",]$`% Without RBO or Treaty`,
                     max(df2[df2$species_type=="Endemic, Small Occurrence Region with ETI>80",]$`% Without Treaty`),
                     max(df2[df2$species_type=="Endemic, Small Occurrence Region with ETI>80",]$`% Without RBO`),
                     max(df2[df2$species_type=="Endemic, Small Occurrence Region with ETI>80",]$`% Without RBO or Treaty`)
)


print(para1)
print(para2)
