
# terrestrial vertebrates category #
terr_vertebrates_category <- c('Amphibians','Birds','Mammals','Reptiles') # not fish
master_tab_species_groups_cat <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  dplyr::mutate(species_groups = ifelse(grp %in% terr_vertebrates_category,'Terr. Vertebrates [Class]',
                                        ifelse(grp=='Fish','Fish',
                                               ifelse(startsWith(grp, "Arthropods_"),"Arthropods [Order]",
                                                      ifelse(startsWith(grp,'Plants_'),'Vascular Plants [Order]',
                                                             ifelse(grp=="Animals_Other","Mollusca",grp)))))) %>%
  dplyr::mutate(species_subgroups = ifelse(str_detect(grp, "_"),str_split_i(grp,"_", 2),grp)) %>%
  dplyr::mutate(species_group_cat = paste(species_groups,species_subgroups,sep="_")) %>%
  # select species only so unique/distinct
  dplyr::select(species,species_groups,species_group_cat) %>%
  distinct() %>%
  dplyr::group_by(species_groups,species_group_cat) %>%
  arrange(species_groups) %>%
  dplyr::summarize(n_spp_total = n()) %>%
  as.data.frame()

print(sprintf("Total species : %s", sum(master_tab_species_groups_cat$n_spp_total,na.rm=T)))

master_tab_species_groups_cat_fn <- file.path(tbldir,'fig_01_species_info_by_species_group_subcategory.csv')
write.csv(master_tab_species_groups_cat,master_tab_species_groups_cat_fn,row.names= FALSE)

# number of endemics
table(master_tab$d_endemic100)
table(master_tab$method)

master_tab_species_stats <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,incgrp2023)) %>%
  dplyr::group_by(species,order) %>%
  dplyr::summarize(area = sum(area,na.rm = TRUE),
                   d_endemic100 = max(d_endemic100),
                   d_assignedrisk = max(d_assignedrisk),
                   d_alphahull = ifelse(method == "AlphaHull",1,0)) %>%
  ungroup() %>%
  distinct() %>%
  dplyr::mutate(d_small25k = ifelse(area < 25 * 25, 1,0 )) %>%
  dplyr::mutate(d_small50k = ifelse(area < 50 * 50, 1,0 )) %>%
  dplyr::summarize(n_endemic100 = sum(d_endemic100,na.rm=TRUE),
                   n_small25k = sum(d_small25k,na.rm=TRUE),
                   n_assignedrisk = sum(d_assignedrisk, na.rm = TRUE),
                   n_alphahull = sum(d_alphahull, na.rm = TRUE),
                   n_species = n(),
                   n_small50k = sum(d_small50k,na.rm=TRUE)) %>%
  dplyr::mutate(n_woutrisk = n_species - n_assignedrisk)
  
master_tab_species_stats

##
## Figure 8 
##

# used in excel
order_of_levels <- c("Terr. Vertebrates [Class]","Fish","Arthropods [Order]","Mollusca",
                     "Animals_Other","Vascular Plants [Order]","Fungi",
                   "Kingdoms_Other")

master_tab_species_group_all <- master_tab %>%
  dplyr::select(species,grp,phylum,d_endemic100,area,pthreat) %>%
  dplyr::mutate(species_groups = ifelse(grp %in% terr_vertebrates_category,'Terr. Vertebrates [Class]',
                                        ifelse(grp=='Fish',"Fish",
                                               ifelse(startsWith(grp, "Arthropods_"),"Arthropods [Order]",
                                                      ifelse(startsWith(grp,'Plants_'),'Vascular Plants [Order]',
                                                             ifelse(grp=="Animals_Other"&phylum=="Mollusca","Mollusca",grp)))))) %>%
  dplyr::select(!c(phylum,grp)) %>%
  dplyr::filter(!is.na(area)) %>%
  dplyr::filter(!is.na(pthreat)) %>%
  dplyr::filter(!is.na(d_endemic100)) %>%
  dplyr::group_by(species,species_groups) %>%
  distinct() %>%
  dplyr::summarize(area = max(area,na.rm=TRUE),
                   d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE)) %>%
  dplyr::ungroup() %>%
  
  mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)) %>%
  dplyr::mutate(f_species_groups = factor(species_groups, levels = order_of_levels)) %>%
  distinct() %>%
  dplyr::group_by(f_species_groups) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                  
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())
  
master_tab_species_group_all

print(sprintf("Total species : %s", sum(master_tab_species_group_all$n_spp_total,na.rm=T)))

names(master_tab_species_group_all)
attr(master_tab_species_group_all$f_species_groups,'label') <- 'species group'
attr(master_tab_species_group_all$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(master_tab_species_group_all$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(master_tab_species_group_all$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(master_tab_species_group_all$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(master_tab_species_group_all$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(master_tab_species_group_all$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(master_tab_species_group_all$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(master_tab_species_group_all$n_spp_total,'label') <- 'Number of total species'
summary(master_tab_species_group_all)

master_tab_species_group_all_fn <- file.path(tbldir,sprintf('global_species_all_summary%s.dta',Sys.Date()))
haven::write_dta(master_tab_species_group_all,master_tab_species_group_all_fn)

# clean-up
rm(master_tab_species_group_all)