##
## Species by FCS territories
##

## territories
bnddisp_df <- bndp %>%
  dplyr::mutate(area_km2 = round(as.numeric(st_area(.) / 1000000),1)) %>%
  st_drop_geometry()
names(bnddisp_df)

bndfcv_df <- bnddisp_df %>% dplyr::select(gid,WB_REGION,Continent,Continent_Code,ISO_A2)

# FCV entities
fcv_entity_fn <- file.path(localdir,'tab_data','fcv.xlsx')
fcv_entity <- readxl::read_excel(fcv_entity_fn) %>%
  dplyr::rename(WB_ISO = WB_IS0)
fcv_entity_ids <- fcv_entity %>%
  dplyr::select(gid) %>%
  pull()

##
## summary by entity
##
master_tab_fcv <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  # entity ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  dplyr::filter(entity_ids %in% c(fcv_entity_ids)) %>%
  mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)) %>%
  dplyr::group_by(entity_ids) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())

# merge FCV
fcv_spp_out <- merge(master_tab_fcv,bnddisp_df,by.x='entity_ids',by.y='gid',all.x=T) %>%
  dplyr::select(!c("ISO_A3","WB_ISO")) %>%
  dplyr::select(c("bndtype","type", "WB_DATANAM", "entity_ids",everything())) %>%
  arrange(bndtype,desc(type), WB_DATANAM)

# merge FCV classification
fcv_spp_out_class <- merge(fcv_spp_out,fcv_entity,by.x='entity_ids',by.y='gid',all.x=T)

# output
fcv_spp_out_fn <- file.path(tbldir,sprintf('fcv_species_summary%s.csv',Sys.Date()))
write.csv(fcv_spp_out_class,fcv_spp_out_fn,row.names=F)

names(fcv_spp_out_class)
attr(fcv_spp_out_class$entity_ids,'label') <- 'entity identifiers'
attr(fcv_spp_out_class$bndtype,'label') <- 'boundary type'
attr(fcv_spp_out_class$type,'label') <- 'land and/or EEZ'
attr(fcv_spp_out_class$WB_DATANAM,'label') <- 'entity name'
attr(fcv_spp_out_class$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(fcv_spp_out_class$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(fcv_spp_out_class$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(fcv_spp_out_class$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(fcv_spp_out_class$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(fcv_spp_out_class$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(fcv_spp_out_class$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(fcv_spp_out_class$n_spp_total,'label') <- 'Number of total species'
attr(fcv_spp_out_class$country_name,'label') <- 'country name'
attr(fcv_spp_out_class$fcv_status,'label') <- 'FCV status'
attr(fcv_spp_out_class$fiscal_year,'label') <- 'Fiscal year'
attr(fcv_spp_out_class$WB_ISO,'label') <- 'ISO code'

attr(fcv_spp_out_class$area_km2,'label') <- 'Area (km2)'

attr(fcv_spp_out_class$WB_REGION,'label') <- 'World Bank Region'
attr(fcv_spp_out_class$Continent,'label') <- 'Continent'
attr(fcv_spp_out_class$Continent_Code,'label') <- 'Continent Code'
attr(fcv_spp_out_class$ISO_A2,'label') <- 'ISO A2'


fcv_spp_out_class_dta_fn <- file.path(tbldir,sprintf('fcv_species_summary%s.dta',Sys.Date()))
haven::write_dta(fcv_spp_out_class,fcv_spp_out_class_dta_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(fcv_spp_out_class),
  Label = sapply(fcv_spp_out_class, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('fcv_species_summary_labels%s.csv',Sys.Date())), row.names = FALSE)


##
## Summarize all
##
terr_vertebrates_category <- c('Amphibians','Birds','Mammals','Reptiles') # not fish
master_tab_fcv_all <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  dplyr::mutate(species_groups = ifelse(grp %in% terr_vertebrates_category,'Terr. Vertebrates [Class]',
                                        # added fish separate from terr verte
                                        ifelse(grp=='Fish',"Fish",
                                               ifelse(startsWith(grp, "Arthropods_"),"Arthropods [Order]",
                                                      ifelse(startsWith(grp,'Plants_'),'Vascular Plants [Order]',
                                                             ifelse(grp=="Animals_Other"&phylum=="Mollusca","Mollusca",grp)))))) %>%
  dplyr::mutate(species_subgroups = ifelse(str_detect(grp, "_"),str_split_i(grp,"_", 2),grp)) %>%
  dplyr::mutate(species_group_cat = paste(species_groups,species_subgroups,sep="_")) %>%
  # entity ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  dplyr::filter(entity_ids %in% c(fcv_entity_ids)) %>%
  dplyr::select(-entity_ids) %>%
  
  dplyr::group_by(species,species_groups) %>%
  distinct() %>%
  
  dplyr::summarize(area = max(area,na.rm=TRUE),
                   d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE)) %>%
  dplyr::ungroup() %>%
  
  distinct() %>%
  
  mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)) %>%
  dplyr::group_by(species_groups) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n()) %>%
  dplyr::mutate(bndtype = 'fcv countries')

# change row order
master_tab_fcv_all <- master_tab_fcv_all %>%
  mutate(species_groups_label = as.character(factor(species_groups,
                                                    labels=c('Other Animals','Arthropods',
                                                             'Fish','Fungi','Other non-animal non-plant species',
                                                             'Mollusca','Terrestrial Vertebrates',
                                                             'Vascular Plants')))) %>%
  dplyr::mutate(species_groups_label = factor(species_groups_label,
                                              levels=desired_species_group_order)) %>%
  arrange(species_groups_label) %>%
  relocate(species_groups_label) %>%
  relocate(species_groups, .after = last_col())


names(master_tab_fcv_all)
attr(master_tab_fcv_all$bndtype,'label') <- 'boundary type'
attr(master_tab_fcv_all$species_groups,'label') <- 'species group'
attr(master_tab_fcv_all$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(master_tab_fcv_all$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(master_tab_fcv_all$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(master_tab_fcv_all$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(master_tab_fcv_all$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(master_tab_fcv_all$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(master_tab_fcv_all$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(master_tab_fcv_all$n_spp_total,'label') <- 'Number of total species'
summary(master_tab_fcv_all)

master_tab_fcv_all_fn <- file.path(tbldir,sprintf('fcv_species_all_summary%s.dta',Sys.Date()))
haven::write_dta(master_tab_fcv_all,master_tab_fcv_all_fn)

# Export the labels table to CSV
master_tab_fcv_all_csv_fn <- file.path(tbldir,sprintf('fcv_species_all_summary%s.csv',Sys.Date()))
write.csv(master_tab_fcv_all, master_tab_fcv_all_csv_fn, row.names = FALSE)


# Create a table of labels
labels_table <- data.frame(
  Variable = names(fcv_spp_out_class),
  Label = sapply(fcv_spp_out_class, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('fcv_species_all_summary_labels%s.csv',Sys.Date())), row.names = FALSE)


##
## summary by Continent
##
master_tab_fcv_entity <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  # entity ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  dplyr::filter(entity_ids %in% c(fcv_entity_ids)) %>%
  
  mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0))

master_tab_fcv_continent <- merge(master_tab_fcv_entity,bndfcv_df,by.x='entity_ids',by.y='gid',all.x=T) %>%
  dplyr::group_by(Continent) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())



master_tab_fcv_continent <- master_tab_fcv_continent %>%
  dplyr::mutate(continent_label = factor(Continent,
                                         labels = c("Africa",
                                                    "Asia",
                                                    "Europe",
                                                    "North America",
                                                    "Oceania",
                                                    "South America",
                                                    "Across continents"
                                         ),
                                         levels=desired_continent_order)) %>%
  arrange(continent_label) %>%
  relocate(continent_label) %>%
  relocate(continent_label, .after = last_col())

master_tab_fcv_continent_fn <- file.path(tbldir,sprintf('fcv_species_continent_summary%s.csv',Sys.Date()))
write.csv(master_tab_fcv_continent,master_tab_fcv_continent_fn,row.names=FALSE)