##
## Produce geographic union (ie total)
## across the geographic areas
##

## Inputs

##
## JOINT GID
##
bnddisp <- bndp %>%
  dplyr::filter(bndtype=="joint") %>%
  st_drop_geometry()

jointterr_entity_gid <- bnddisp %>%
  dplyr::select(gid) %>%
  pull()

##
## disputed GID
##
bnddisp_df <- bndp %>%
  dplyr::filter(bndtype=="disputed")  %>%
  st_drop_geometry()

dispterr_entity_gid <- bnddisp_df %>%
  dplyr::select(gid) %>%
  pull()

##
## FCV GID
##
# FCV entities
fcv_entity_fn <- file.path(localdir,'tab_data','fcv.xlsx')
fcv_entity <- readxl::read_excel(fcv_entity_fn) %>%
  dplyr::rename(WB_ISO = WB_IS0)
fcv_entity_ids <- fcv_entity %>%
  dplyr::select(gid) %>%
  pull()

## Union of GIDs ##
union_gid <- sort(unique(c(jointterr_entity_gid,dispterr_entity_gid,fcv_entity_ids)))


## basins
tfdd_fn <- file.path(localdir,'geo_data','TFDD_SpatialData_Public202203','BasinMaster311_20220224.shp')
tfdd_raw <- read_sf(tfdd_fn)
tfdd <- st_transform(tfdd_raw,4326) %>%
  mutate(bid = row_number()) %>%
  dplyr::select(BCODE,Basin_Name,Continent_,Area_km2,bid)

tfdd_bid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::select(bid) %>%
  pull()

union_bid <- sort(unique(tfdd_bid))


# Produce statistics for entire set of geographic areas (union) #
union_areas <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  
  dplyr::select(!c(max_sh_entity_id,max_sh_entity,max_sh_spp,max_sh_basin,
                   spp_occ_garea,max_sh_bid,max_sh_spp_basin,n_basins,
                   spp_occ_shparea,n_entities,popgroupmax,lcat,method,
                   kingdom,rcat,WB_ISO,ISO_A3,max_sh_spp_basin,
                   WB_DATANAM,order,family,popden,genus,phylum,type,
                   bndtype,class,grp)) %>%
  dplyr::filter(!is.na(area)) %>%
  
  distinct() %>%
  
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  
  # gid ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  
  # in basin OR country
  dplyr::filter((basin_bids %in% c(union_bid)) | (entity_ids %in% c(union_gid))) %>%
  
  # drop identifiers and keep distinct rows
  dplyr::select(-c(entity_ids,basin_bids)) %>%
  distinct() %>%
  
  # take largest area for species level
  #group_by(species) %>%
  #slice_max(area, n = 1, na_rm = TRUE) %>%
  #ungroup() %>%

  dplyr::group_by(species) %>%
  distinct() %>%
  dplyr::summarize(area = max(area,na.rm=TRUE),
                   d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE)) %>%
  dplyr::ungroup() %>%
  
  
  # calculate statistics at species level across entities
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)
                ) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())

 
union_areas$n_spp_total
union_areas_fn <- file.path(tbldir,sprintf('union_areas_species_summary%s.csv',Sys.Date()))
write.csv(union_areas,union_areas_fn,row.names=F)

names(union_areas)
attr(union_areas$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(union_areas$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(union_areas$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(union_areas$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(union_areas$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(union_areas$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(union_areas$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(union_areas$n_spp_total,'label') <- 'Number of total species'

union_areas_dta_fn <- file.path(tbldir,sprintf('union_areas_species_summary%s.dta',Sys.Date()))
haven::write_dta(union_areas,union_areas_dta_fn)

# csv format
union_areas_csv_fn <- file.path(tbldir,sprintf('union_areas_species_summary%s.csv',Sys.Date()))
data.table::fwrite(union_areas,union_areas_csv_fn)


# Create a table of labels
labels_table <- data.frame(
  Variable = names(union_areas),
  Label = sapply(union_areas, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('union_areas_species_summary_labels%s.csv',Sys.Date())), row.names = FALSE)
