##
## International river basins
##

## basins
tfdd_fn <- file.path(localdir,'geo_data','TFDD_SpatialData_Public202203','BasinMaster311_20220224.shp')
tfdd_raw <- read_sf(tfdd_fn)
tfdd <- st_transform(tfdd_raw,4326) %>%
  mutate(bid = row_number()) %>%
  dplyr::select(BCODE,Basin_Name,Continent_,Area_km2,bid)


# intersect with World Bank regions
tfddbasin_df <- tfdd %>% st_drop_geometry() %>%
  dplyr::rename(Continent_Code = Continent_) %>%
  dplyr::mutate(Continent = case_when(
    Continent_Code == "AF" ~ "Africa",
    Continent_Code == "AS" ~ "Asia",
    Continent_Code == "EU" ~ "Europe",
    Continent_Code == "NA" ~ "North America",
    Continent_Code == "SA" ~ "South America",
    TRUE ~ "NA"  # Catch-all for any other values
  ))
  

tfddbasin_continent_df <- tfddbasin_df %>%
  dplyr::select(bid,Continent)

tfdd_gid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::select(bid) %>%
  pull()


# 
tfddbasins <- master_tab %>%
  dplyr::select(species,entity_ids,basin_bids, d_endemic100, pthreat,
                area) %>%
  #dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
  #                 natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  dplyr::filter(basin_bids %in% c(tfdd_gid)) %>%
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)
                ) %>%
  dplyr::group_by(basin_bids) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())


# merge basins
tfddbasins_spp_out <- merge(tfddbasins,tfddbasin_df,by.x='basin_bids',by.y='bid',all.x=T) %>%
  dplyr::select(c("Continent", "Basin_Name", "BCODE","basin_bids",everything())) %>%
  arrange(Continent,Basin_Name)

dim(tfddbasins_spp_out)
head(tfddbasins_spp_out)

tfddbasins_spp_out_fn <- file.path(tbldir,sprintf('tfddbasins_species_summary%s.csv',Sys.Date()))
write.csv(tfddbasins_spp_out,tfddbasins_spp_out_fn,row.names=F)

names(tfddbasins_spp_out)
attr(tfddbasins_spp_out$Continent,'label') <- 'continent'
attr(tfddbasins_spp_out$Basin_Name,'label') <- 'basin name'
attr(tfddbasins_spp_out$BCODE,'label') <- 'basin code'
attr(tfddbasins_spp_out$basin_bids,'label') <- 'basin identifier'
attr(tfddbasins_spp_out$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(tfddbasins_spp_out$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(tfddbasins_spp_out$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(tfddbasins_spp_out$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(tfddbasins_spp_out$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(tfddbasins_spp_out$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(tfddbasins_spp_out$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(tfddbasins_spp_out$n_spp_total,'label') <- 'Number of total species'
attr(tfddbasins_spp_out$Area_km2,'label') <- 'Area (km2)'

tfddbasins_spp_out_dta_fn <- file.path(tbldir,sprintf('tfddbasins_species_summary%s.dta',Sys.Date()))
haven::write_dta(tfddbasins_spp_out,tfddbasins_spp_out_dta_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(dispterr_all),
  Label = sapply(dispterr_all, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('tfddbasins_species_summary_labels%s.csv',Sys.Date())), row.names = FALSE)


##
## all basins
##

terr_vertebrates_category <- c('Amphibians','Birds','Mammals','Reptiles') # not fish
tfddbasins_all <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  dplyr::mutate(species_groups = ifelse(grp %in% terr_vertebrates_category,'Terr. Vertebrates [Class]',
                                        # added fish separate from terr verte
                                        ifelse(grp=='Fish',"Fish",
                                               ifelse(startsWith(grp, "Arthropods_"),"Arthropods [Order]",
                                                      ifelse(startsWith(grp,'Plants_'),'Vascular Plants [Order]',
                                                             ifelse(grp=="Animals_Other"&phylum=="Mollusca","Mollusca",grp)))))) %>%
  dplyr::mutate(species_subgroups = ifelse(str_detect(grp, "_"),str_split_i(grp,"_", 2),grp)) %>%
  dplyr::mutate(species_group_cat = paste(species_groups,species_subgroups,sep="_")) %>%

  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  dplyr::filter(basin_bids %in% c(tfdd_gid)) %>%
  dplyr::select(-basin_bids) %>%
  dplyr::group_by(species) %>%
  slice_max(area,n=1) %>%
  dplyr::ungroup() %>%
  distinct() %>%
  
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
                d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)
  ) %>%
  dplyr::group_by(species_groups) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())

# change species group row order
tfddbasins_all <- tfddbasins_all %>%
  mutate(species_groups_label = as.character(factor(species_groups,
                                                    labels=c('Other Animals','Arthropods',
                                                             'Fish','Fungi','Other non-animal non-plant species',
                                                             'Mollusca','Terrestrial Vertebrates',
                                                             'Vascular Plants')))) %>%
  dplyr::mutate(species_groups_label = factor(species_groups_label,
                                              levels=desired_species_group_order)) %>%
  arrange(species_groups_label) %>%
  relocate(species_groups_label) %>%
  relocate(species_groups, .after = last_col())

tfddbasins_all_fn <- file.path(tbldir,sprintf('tfddbasins_species_all_summary%s.csv',Sys.Date()))
write.csv(tfddbasins_all,tfddbasins_all_fn,row.names=F)

names(tfddbasins_all)
attr(tfddbasins_all$species_groups_label,'label') <- 'species groups label'
attr(tfddbasins_all$species_groups,'label') <- 'species groups'
attr(tfddbasins_all$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(tfddbasins_all$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'

attr(tfddbasins_all$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(tfddbasins_all$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(tfddbasins_all$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(tfddbasins_all$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'
attr(tfddbasins_all$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'
attr(tfddbasins_all$n_spp_total,'label') <- 'Number of total species'

tfddbasins_all_dta_fn <- file.path(tbldir,sprintf('tfddbasins_species_all_summary%s.dta',Sys.Date()))
haven::write_dta(tfddbasins_all,tfddbasins_all_dta_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(tfddbasins_all),
  Label = sapply(tfddbasins_all, attr, "label")
)

summary(tfddbasins_all)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('tfddbasins_species_all_summary_labels%s.csv',Sys.Date())), row.names = FALSE)


##
## river basin (collapsed) ALL Continent
##
tfddbasins_bids <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  dplyr::filter(basin_bids %in% c(tfdd_gid))
  
master_tab_basin_continent <- merge(tfddbasins_bids,tfddbasin_continent_df,by.x='basin_bids',by.y='bid',all.x=T) %>%
  dplyr::select(-c(basin_bids)) %>%
  dplyr::group_by(species) %>%
  slice_max(area,n=1) %>%
  dplyr::ungroup() %>%
  
  distinct() %>%
  mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)) %>%

  dplyr::group_by(Continent) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())

master_tab_basin_continent <- master_tab_basin_continent %>%
  dplyr::mutate(continent_label = factor(Continent,
                                         labels = c("Africa",
                                                    "Asia",
                                                    "Europe",
                                                    "North America",
                                                    "Oceania",
                                                    "South America",
                                                    "Across continents"
                                         ),
                                         levels=desired_continent_order)) %>%
  arrange(continent_label) %>%
  relocate(continent_label) %>%
  relocate(continent_label, .after = last_col())
table(master_tab_basin_continent$continent_label)

master_tab_basin_continent$n_spp_total

master_tab_basin_continent_fn <- file.path(tbldir,sprintf('tfddbasins_species_continent_summary%s.csv',Sys.Date()))
write.csv(master_tab_basin_continent,master_tab_basin_continent_fn,row.names=FALSE)


##
## all basins
##

##
## need geographic union for table
##

terr_vertebrates_category <- c('Amphibians','Birds','Mammals','Reptiles') # not fish
tfddbasins_all_sum <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  dplyr::filter(basin_bids %in% c(tfdd_gid)) %>%
  dplyr::select(-basin_bids) %>%
  # take largest area for species level
  group_by(species,pthreat,d_endemic100) %>%
  dplyr::summarize(d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE),
                   area = max(area,na.rm=TRUE)) %>%
  ungroup() %>%
  
  distinct() %>%
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
                d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)
  ) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())

print(sprintf("Total unique species in basins : %s", sum(tfddbasins_all_sum$n_spp_total,na.rm=T)))

master_tab_basin_all_fn <- file.path(tbldir,sprintf('tfddbasins_species_allbasins_summary%s.csv',Sys.Date()))
write.csv(tfddbasins_all_sum,master_tab_basin_all_fn,row.names=FALSE)

# clean-up
rm(tfddbasins_all_sum)