##
## International river basins
##

## Inputs

## basins
tfdd_fn <- file.path(localdir,'geo_data','TFDD_SpatialData_Public202203','BasinMaster311_20220224.shp')
tfdd_raw <- read_sf(tfdd_fn)
tfdd <- st_transform(tfdd_raw,4326) %>%
  mutate(bid = row_number()) %>%
  dplyr::select(BCODE,Basin_Name,Continent_,Area_km2,bid)


# intersect with World Bank regions
tfddbasin_df <- tfdd %>% st_drop_geometry() %>%
  dplyr::rename(Continent_Code = Continent_) %>%
  dplyr::mutate(Continent = case_when(
    Continent_Code == "AF" ~ "Africa",
    Continent_Code == "AS" ~ "Asia",
    Continent_Code == "EU" ~ "Europe",
    Continent_Code == "NA" ~ "North America",
    Continent_Code == "SA" ~ "South America",
    TRUE ~ "NA"  # Catch-all for any other values
  ))
  

tfddbasin_continent_df <- tfddbasin_df %>%
  dplyr::select(bid,Continent)

tfdd_gid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::select(bid) %>%
  pull()





##
## all basins
##
desired_species_group_order <- c('Terrestrial Vertebrates','Fish','Arthropods',
                                 'Mollusca','Other Animals','Vascular Plants',
                                 'Fungi','Other Species')

terr_vertebrates_category <- c('Amphibians','Birds','Mammals','Reptiles') # not fish
tfddbasins_all_x_species_groups <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  dplyr::mutate(species_groups = ifelse(grp %in% terr_vertebrates_category,'Terr. Vertebrates [Class]',
                                        # added fish separate from terr verte
                                        ifelse(grp=='Fish',"Fish",
                                               ifelse(startsWith(grp, "Arthropods_"),"Arthropods [Order]",
                                                      ifelse(startsWith(grp,'Plants_'),'Vascular Plants [Order]',
                                                             ifelse(grp=="Animals_Other"&phylum=="Mollusca","Mollusca",grp)))))) %>%
  dplyr::mutate(species_subgroups = ifelse(str_detect(grp, "_"),str_split_i(grp,"_", 2),grp)) %>%
  dplyr::mutate(species_group_cat = paste(species_groups,species_subgroups,sep="_")) %>%

  mutate(species_groups_label = (factor(species_groups,
                                        labels=c('Other Animals','Arthropods',
                                                 'Fish','Fungi','Other Species',
                                                 'Mollusca','Terrestrial Vertebrates',
                                                 'Vascular Plants')))) %>%
  dplyr::mutate(species_groups_label = factor(species_groups_label,
                                              levels=desired_species_group_order)) %>%
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  dplyr::filter(basin_bids %in% c(tfdd_gid)) %>%
  #dplyr::select(-basin_bids) %>%
  distinct() %>%
  dplyr::mutate(d_smallocc25 = ifelse(area <= 25*25,1,0),
                d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small25xTprob80 = ifelse(d_smallocc25==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc25xEndemic100 = ifelse(d_smallocc25==1 & d_endemic100==1,1,0),
                d_smallocc25xEndemic100xTprob80 = 
                  ifelse(d_smallocc25==1 & d_endemic100==1 & d_tprob80==1,1,0)
  ) %>%
  dplyr::group_by(basin_bids,species_groups_label) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small25 = sum(d_smallocc25,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small25xEndemic100 = sum(d_smallocc25xEndemic100,na.rm=T),
                   n_spp_small25xTprob80 = sum(d_spp_small25xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small25xEndemic100xTprob80 = sum(d_smallocc25xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())


# merge basins
tfddbasins_spp_groups_out <- merge(tfddbasins_all_x_species_groups,tfddbasin_df,by.x='basin_bids',by.y='bid',all.x=T) %>%
  dplyr::select(c("Continent", "Basin_Name", "BCODE","basin_bids",everything())) %>%
  arrange(Continent,Basin_Name)

dim(tfddbasins_spp_groups_out)
head(tfddbasins_spp_groups_out)

tfddbasins_spp_groups_out_fn <- file.path(tbldir,sprintf('tfddbasins_x_species_groups_indicators_%s.csv',Sys.Date()))
write.csv(tfddbasins_spp_groups_out,tfddbasins_spp_groups_out_fn,row.names=F)


names(tfddbasins_spp_groups_out)
attr(tfddbasins_spp_groups_out$Continent,'label') <- 'continent'
attr(tfddbasins_spp_groups_out$Continent_Code,'label') <- 'continent code'
attr(tfddbasins_spp_groups_out$species_groups_label,'label') <- 'Species groups'
attr(tfddbasins_spp_groups_out$Basin_Name,'label') <- 'basin name'
attr(tfddbasins_spp_groups_out$BCODE,'label') <- 'basin code'
attr(tfddbasins_spp_groups_out$basin_bids,'label') <- 'basin identifier'
attr(tfddbasins_spp_groups_out$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(tfddbasins_spp_groups_out$n_spp_small25,'label') <- 'Number of species with small occurrence regions (25x25)'
attr(tfddbasins_spp_groups_out$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(tfddbasins_spp_groups_out$n_spp_small25xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (25x25)'
attr(tfddbasins_spp_groups_out$n_spp_small25xTprob80,'label') <- 'Number of species with small occurrence regions (25x25) and tprob>=80'
attr(tfddbasins_spp_groups_out$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(tfddbasins_spp_groups_out$n_spp_small25xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (25x25) and tprob>=80'

attr(tfddbasins_spp_groups_out$n_spp_total,'label') <- 'Number of total species'
attr(tfddbasins_spp_groups_out$Area_km2,'label') <- 'Area (km2)'

tfddbasins_spp_groups_out_dta_fn <- file.path(tbldir,sprintf('tfddbasins_x_species_groups_indicators_%s.dta',Sys.Date()))
haven::write_dta(tfddbasins_spp_groups_out,tfddbasins_spp_groups_out_dta_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(tfddbasins_spp_groups_out),
  Label = sapply(tfddbasins_spp_groups_out, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('tfddbasins_x_species_groups_indicators_labels%s.csv',Sys.Date())), row.names = FALSE)

