##
## Joint territories
##


## Inputs
bnddisp <- bndp %>%
  dplyr::filter(bndtype=="joint") %>%
  dplyr::mutate(area_km2 = round(as.numeric(st_area(.) / 1000000),1)) %>%
  st_drop_geometry()


jointterr_entity_gid <- bnddisp %>%
  dplyr::select(gid) %>%
  pull()


# 
jointterr <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  # entity ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  dplyr::filter(entity_ids %in% c(jointterr_entity_gid)) %>%
  
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)) %>%
  dplyr::group_by(entity_ids) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())

names(jointterr)
# merge joint
joint_spp_out <- merge(jointterr,bnddisp,by.x='entity_ids',by.y='gid',all.x=T) %>%
  dplyr::select(!c("ISO_A3","WB_ISO")) %>%
  dplyr::select(c("bndtype","type", "WB_DATANAM", "entity_ids",everything())) %>%
  arrange(bndtype,desc(type), WB_DATANAM)

dim(joint_spp_out)
head(joint_spp_out)
summary(joint_spp_out)

joint_spp_out_fn <- file.path(tbldir,sprintf('joint_species_summary%s.csv',Sys.Date()))
write.csv(joint_spp_out,joint_spp_out_fn,row.names=F)

names(joint_spp_out)
attr(joint_spp_out$bndtype,'label') <- 'boundary type'
attr(joint_spp_out$type,'label') <- 'land and/or EEZ'
attr(joint_spp_out$WB_DATANAM,'label') <- 'entity name'
attr(joint_spp_out$entity_ids,'label') <- 'entity identifiers'

attr(joint_spp_out$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(joint_spp_out$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(joint_spp_out$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(joint_spp_out$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(joint_spp_out$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(joint_spp_out$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(joint_spp_out$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(joint_spp_out$n_spp_total,'label') <- 'Number of total species'

attr(joint_spp_out$area_km2,'label') <- 'Area (km2)'

attr(joint_spp_out$WB_REGION,'label') <- 'World Bank Region'
attr(joint_spp_out$Continent,'label') <- 'Continent'
attr(joint_spp_out$Continent_Code,'label') <- 'Continent Code'
attr(joint_spp_out$ISO_A2,'label') <- 'ISO A2'


joint_spp_out_dta_fn <- file.path(tbldir,sprintf('joint_species_summary%s.dta',Sys.Date()))
haven::write_dta(joint_spp_out,joint_spp_out_dta_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(joint_spp_out),
  Label = sapply(joint_spp_out, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('joint_species_summary_labels%s.csv',Sys.Date())), row.names = FALSE)

##
## Collapse over all joint territories
## by species groups
##

terr_vertebrates_category <- c('Amphibians','Birds','Mammals','Reptiles') # not fish
land_or_coast <- c('Land','Land_Coast')
jointterr_all <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  dplyr::mutate(species_groups = ifelse(grp %in% terr_vertebrates_category,'Terr. Vertebrates [Class]',
                                        # added fish separate from terr verte
                                        ifelse(grp=='Fish',"Fish",
                                               ifelse(startsWith(grp, "Arthropods_"),"Arthropods [Order]",
                                                      ifelse(startsWith(grp,'Plants_'),'Vascular Plants [Order]',
                                                             ifelse(grp=="Animals_Other"&phylum=="Mollusca","Mollusca",grp)))))) %>%
  dplyr::mutate(species_subgroups = ifelse(str_detect(grp, "_"),str_split_i(grp,"_", 2),grp)) %>%
  dplyr::mutate(species_group_cat = paste(species_groups,species_subgroups,sep="_")) %>%
  # entity ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  dplyr::filter(entity_ids %in% c(jointterr_entity_gid)) %>%
  dplyr::select(-entity_ids) %>%
  distinct() %>%
  
  dplyr::group_by(species,species_groups) %>%
  distinct() %>%
  dplyr::summarize(area = max(area,na.rm=TRUE),
                   d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE)) %>%
  dplyr::ungroup() %>%
  
  #dplyr::filter(!(lcat %in% land_or_coast)) %>%
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
                d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)) %>%
  dplyr::group_by(species_groups) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n()) %>%
  dplyr::mutate(bndtype = 'joint')
  

# change species group row order
jointterr_all <- jointterr_all %>%
  mutate(species_groups_label = as.character(factor(species_groups,
                                                    labels=c('Other Animals','Arthropods',
                                                             'Fish','Fungi','Other non-animal non-plant species',
                                                             'Mollusca','Terrestrial Vertebrates',
                                                             'Vascular Plants')))) %>%
  dplyr::mutate(species_groups_label = factor(species_groups_label,
                                              levels=desired_species_group_order)) %>%
  dplyr::filter(!(species_groups %in% 'Terr. Vertebrates [Class]')) %>%
  arrange(species_groups_label) %>%
  relocate(species_groups_label) %>%
  relocate(species_groups, .after = last_col())


summary(jointterr_all)
names(jointterr_all)
attr(jointterr_all$bndtype,'label') <- 'boundary type'
attr(jointterr_all$species_groups,'label') <- 'species groups'
attr(jointterr_all$species_groups_label,'label') <- 'species groups label'
attr(jointterr_all$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(jointterr_all$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'

attr(jointterr_all$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(jointterr_all$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(jointterr_all$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(jointterr_all$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'
attr(jointterr_all$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'
attr(jointterr_all$n_spp_total,'label') <- 'Number of total species'

jointterr_all_fn <- file.path(tbldir,sprintf('joint_species_all_summary%s.dta',Sys.Date()))
haven::write_dta(jointterr_all,jointterr_all_fn)

# Export the labels table to CSV
jointterr_all_csv_fn <- file.path(tbldir,sprintf('joint_species_all_summary%s.csv',Sys.Date()))
write.csv(jointterr_all, jointterr_all_csv_fn, row.names = FALSE)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(jointterr_all),
  Label = sapply(jointterr_all, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('joint_species_all_summary_labels%s.csv',Sys.Date())), row.names = FALSE)





##
## joint (collapsed) ALL Continent
##
master_tab_joint_entity <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  # entity ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  dplyr::filter(entity_ids %in% c(jointterr_entity_gid)) %>%
  mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0))

master_tab_joint_continent <- merge(master_tab_joint_entity,bnddisp,by.x='entity_ids',by.y='gid',all.x=T) %>%
  dplyr::group_by(Continent) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())

master_tab_joint_continent <- master_tab_joint_continent %>%
  dplyr::mutate(Continent = ifelse(Continent == "North America / Asia","Across continents",Continent)) %>%
  dplyr::mutate(continent_label = factor(Continent,
                                         labels = c("Africa",
                                                    "Asia",
                                                    "Europe",
                                                    "North America",
                                                    "Oceania",
                                                    "South America",
                                                    "Across continents"
                                         ),
                                         levels=desired_continent_order)) %>%
  arrange(continent_label) %>%
  relocate(continent_label) %>%
  relocate(continent_label, .after = last_col())

master_tab_joint_continent_fn <- file.path(tbldir,sprintf('joint_species_continent_summary%s.csv',Sys.Date()))
write.csv(master_tab_joint_continent,master_tab_joint_continent_fn,row.names=FALSE)