## 
## Non determined legal status territories information
##

# entities
bnddisp_df <- bndp %>%
  dplyr::filter(bndtype=="disputed")  %>%
  dplyr::mutate(area_km2 = round(as.numeric(st_area(.) / 1000000),1)) %>%
  st_drop_geometry()

dispterr_entity_gid <- bnddisp_df %>%
  dplyr::select(gid) %>%
  pull()

# 
dispterr <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  # entity ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  dplyr::filter(entity_ids %in% c(dispterr_entity_gid)) %>%
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)
                ) %>%
  distinct() %>%
  dplyr::group_by(entity_ids) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())

# merge disputed
disp_spp_out <- merge(dispterr,bnddisp_df,by.x='entity_ids',by.y='gid',all.x=T) %>%
  dplyr::select(!c("ISO_A3","WB_ISO")) %>%
  dplyr::select(c("bndtype","type", "WB_DATANAM", "entity_ids",everything())) %>%
  arrange(bndtype,WB_DATANAM,desc(type))

disp_spp_out_fn <- file.path(tbldir,sprintf('disputed_species_summary%s.csv',Sys.Date()))
write.csv(disp_spp_out,disp_spp_out_fn,row.names=F)

names(disp_spp_out)
attr(disp_spp_out$bndtype,'label') <- 'boundary type'
attr(disp_spp_out$type,'label') <- 'land and/or EEZ'
attr(disp_spp_out$WB_DATANAM,'label') <- 'entity name'
attr(disp_spp_out$entity_ids,'label') <- 'entity identifiers'
attr(disp_spp_out$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(disp_spp_out$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(disp_spp_out$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(disp_spp_out$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(disp_spp_out$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(disp_spp_out$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(disp_spp_out$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(disp_spp_out$n_spp_total,'label') <- 'Number of total species'
attr(disp_spp_out$area_km2,'label') <- 'Area (km2)'

attr(disp_spp_out$WB_REGION,'label') <- 'World Bank Region'
attr(disp_spp_out$Continent,'label') <- 'Continent'
attr(disp_spp_out$Continent_Code,'label') <- 'Continent Code'
attr(disp_spp_out$ISO_A2,'label') <- 'ISO A2'

disp_spp_out_dta_fn <- file.path(tbldir,sprintf('disputed_species_summary%s.dta',Sys.Date()))
haven::write_dta(disp_spp_out,disp_spp_out_dta_fn)


# Create a table of labels
labels_table <- data.frame(
  Variable = names(disp_spp_out),
  Label = sapply(disp_spp_out, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('disputed_species_summary_labels%s.csv',Sys.Date())), row.names = FALSE)

##
## disputed (collapsed) ALL
##
terr_vertebrates_category <- c('Amphibians','Birds','Mammals','Reptiles') # not fish
dispterr_all <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  dplyr::mutate(species_groups = ifelse(grp %in% terr_vertebrates_category,'Terr. Vertebrates [Class]',
                                        # added fish separate from terr verte
                                        ifelse(grp=='Fish',"Fish",
                                               ifelse(startsWith(grp, "Arthropods_"),"Arthropods [Order]",
                                                      ifelse(startsWith(grp,'Plants_'),'Vascular Plants [Order]',
                                                             ifelse(grp=="Animals_Other"&phylum=="Mollusca","Mollusca",grp)))))) %>%
  dplyr::mutate(species_subgroups = ifelse(str_detect(grp, "_"),str_split_i(grp,"_", 2),grp)) %>%
  dplyr::mutate(species_group_cat = paste(species_groups,species_subgroups,sep="_")) %>%
  # entity ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  dplyr::filter(entity_ids %in% c(dispterr_entity_gid)) %>%
  dplyr::select(-entity_ids) %>%
  
  dplyr::group_by(species,species_groups) %>%
  distinct() %>%
  dplyr::summarize(area = max(area,na.rm=TRUE),
                   d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE)) %>%
  dplyr::ungroup() %>%
  
  
  distinct() %>%
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
                d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)) %>%
  dplyr::group_by(species_groups) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n()) %>%
  dplyr::mutate(bndtype = 'disputed territories')
  
# change species group row order
dispterr_all <- dispterr_all %>%
  mutate(species_groups_label = as.character(factor(species_groups,
                                 labels=c('Other Animals','Arthropods',
                                          'Fish','Fungi','Other non-animal non-plant species',
                                          'Mollusca','Terrestrial Vertebrates',
                                          'Vascular Plants')))) %>%
  dplyr::mutate(species_groups_label = factor(species_groups_label,
                                        levels=desired_species_group_order)) %>%
  arrange(species_groups_label) %>%
  relocate(species_groups_label) %>%
  relocate(species_groups, .after = last_col())

dispterr_all_fn <- file.path(tbldir,sprintf('disputed_species_all_summary%s.csv',Sys.Date()))
write.csv(dispterr_all,dispterr_all_fn,row.names=F)

sum(dispterr_all$n_spp_total)

names(dispterr_all)
attr(dispterr_all$bndtype,'label') <- 'boundary type'
attr(dispterr_all$species_groups,'label') <- 'species group'
attr(dispterr_all$species_groups_label,'label') <- 'species group label'
attr(dispterr_all$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(dispterr_all$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(dispterr_all$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(dispterr_all$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(dispterr_all$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(dispterr_all$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(dispterr_all$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(dispterr_all$n_spp_total,'label') <- 'Number of total species'

dispterr_all_dta_fn <- file.path(tbldir,sprintf('disputed_species_all_summary%s.dta',Sys.Date()))
haven::write_dta(dispterr_all,dispterr_all_dta_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(dispterr_all),
  Label = sapply(dispterr_all, attr, "label")
)

summary(dispterr_all)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('disputed_species_all_summary_labels%s.csv',Sys.Date())), row.names = FALSE)




##
## disputed (collapsed) ALL Continent
##
master_tab_disputed_entity <- master_tab %>%
  dplyr::select(!c(parkpct,popdens,eezpct,popshadow,totfishing,
                   natfishing,irisk,d_assignedrisk,incgrp2023)) %>%
  # entity ids col has all entities that intersect
  tidyr::separate_rows(entity_ids, sep = ",") %>%
  dplyr::mutate(entity_ids = as.numeric(stringr::str_trim(entity_ids))) %>%
  dplyr::filter(entity_ids %in% c(dispterr_entity_gid))
dim(master_tab_disputed_entity)

master_tab_disputed_continent <- merge(master_tab_disputed_entity,bnddisp_df,by.x='entity_ids',by.y='gid',all.x=T) %>%
  dplyr::select(-entity_ids) %>%
  # keep rows that are distinct
  distinct()  %>%
  mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)) %>%
  # collapse from entity level to continent level
  dplyr::group_by(Continent) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n())

master_tab_disputed_continent <- master_tab_disputed_continent %>%
  dplyr::mutate(Continent = ifelse(Continent == "Africa / Europe","Across continents",Continent)) %>%
  dplyr::mutate(continent_label = factor(Continent,
                                         labels = c("Africa",
                                                    "Asia",
                                                    "Europe",
                                                    "North America",
                                                    "Oceania",
                                                    "South America",
                                                    "Across continents"
                                         ),
                                            levels=desired_continent_order)) %>%
  arrange(continent_label) %>%
  relocate(continent_label) %>%
  relocate(continent_label, .after = last_col())

master_tab_disputed_continent_fn <- file.path(tbldir,sprintf('disputed_species_continent_summary%s.csv',Sys.Date()))
write.csv(master_tab_disputed_continent,master_tab_disputed_continent_fn,row.names=FALSE)
