##
## International river basins
##

## Inputs

## basins data (different version has treaty variable) 313 basins
## Count of Treaties (Count_of_T)
## Number of documents signed per basin based on the TFDD's International Freshwater Treaties Database as of June 2024.
## Count of River Basin Organizations (Count_of_R)
## Number of RBOs per basin (or within the basin) based on the TFDD's International River Basin Organizations Database as of June 2024.
tfdd_fn <- file.path(localdir,'geo_data','TFDD_SpatialData_Public202203','BasinMaster313_20240807.shp')
tfdd2024_raw <- read_sf(tfdd_fn) %>%
  dplyr::select(BCODE,Count_of_T,Count_of_R) %>%
  st_drop_geometry()

tfdd <- st_transform(tfdd_raw,4326) %>%
  mutate(bid = row_number()) %>%
  dplyr::select(BCODE,Basin_Name,Continent_,Area_km2,bid)

## 311 basins used for overlays
tfdd_fn <- file.path(localdir,'geo_data','TFDD_SpatialData_Public202203','BasinMaster311_20220224.shp')
tfdd_raw <- read_sf(tfdd_fn)
names(tfdd2024_raw)

# add treaty var to shapes
tfdd <- merge(tfdd,tfdd2024_raw,by='BCODE',all.x=TRUE) %>%
  dplyr::mutate(d_treaty = ifelse(Count_of_T>0,1,0),
                d_RBO = ifelse(Count_of_R>0,1,0))

tfdd_basins_df <- tfdd %>% st_drop_geometry()

tfdd_gid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::select(bid) %>%
  pull()

tfdd_treaty_bid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::filter(d_treaty == 1) %>%
  dplyr::select(bid) %>%
  pull()

#
tfdd_no_treaty_bid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::filter(d_treaty == 0) %>%
  dplyr::select(bid) %>%
  pull()
print(sprintf("Count of basins without treaties %s",length(tfdd_no_treaty_bid)))

tfdd_rbo_bid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::filter(d_RBO == 1) %>%
  dplyr::select(bid) %>%
  pull()
print(sprintf("Count of basins with RBO %s",length(tfdd_rbo_bid)))

tfdd_no_rbo_bid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::filter(d_RBO == 0) %>%
  dplyr::select(bid) %>%
  pull()
print(sprintf("Count of basins without RBO %s",length(tfdd_no_rbo_bid)))

# NO RBO AND TREATY NO
tfdd_no_rbo_and_treaty_bid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::filter((d_RBO == 0) & (d_treaty == 0)) %>%
  dplyr::select(bid) %>%
  pull()
print(sprintf("Count of basins without treaties AND a RBO %s",length(tfdd_no_rbo_and_treaty_bid)))

# YES RBO AND TREATY
tfdd_yes_rbo_or_treaty_bid <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::filter(d_RBO == 1 | d_treaty == 1) %>%
  dplyr::select(bid) %>%
  pull()



setdiff(tfdd_no_rbo_bid,tfdd_no_rbo_and_treaty_bid)


tfdd_no_rbo_and_treaty_basins <- tfdd %>%
  st_drop_geometry() %>%
  dplyr::filter(bid %in% setdiff(tfdd_no_treaty_bid,tfdd_no_rbo_and_treaty_bid)) %>%
  dplyr::select(Basin_Name) %>%
  pull()
  

##
## Basins by treaty
##
tfddbasins_no_treaty <- master_tab %>%
  dplyr::select(species,basin_bids, d_endemic100, pthreat,
                area) %>%
  # need data
  dplyr::filter(!is.na(pthreat)) %>%
  dplyr::filter(!is.na(area)) %>%
  
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  # only transboundary basins
  dplyr::filter(basin_bids %in% c(tfdd_gid)) %>%
  # treaty dummy
  dplyr::mutate(d_treaty = ifelse(basin_bids %in% tfdd_treaty_bid,1,0)) %>%
  # if species is in any basin with a treaty
  dplyr::select(-c(basin_bids)) %>%
  # species can be in both 0/1 treaty
  dplyr::group_by(species,pthreat,d_endemic100) %>%
  dplyr::summarize(d_sumtreaty = sum(d_treaty,na.rm=TRUE),
                   d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE),
                   area = max(area,na.rm=TRUE)) %>%
  dplyr::ungroup() %>%
  distinct() %>%
  dplyr::filter(d_sumtreaty==0) %>%
  
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
         d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)
                ) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n()) %>%
  dplyr::mutate(d_treaty=0)


tfddbasins_by_treaty_fn <- file.path(tbldir,sprintf('tfddbasins_no_treaty_species_summary%s.csv',Sys.Date()))
write.csv(tfddbasins_no_treaty,tfddbasins_by_treaty_fn,row.names=F)

names(tfddbasins_no_treaty)
attr(tfddbasins_no_treaty$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(tfddbasins_no_treaty$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(tfddbasins_no_treaty$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(tfddbasins_no_treaty$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(tfddbasins_no_treaty$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(tfddbasins_no_treaty$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(tfddbasins_no_treaty$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(tfddbasins_no_treaty$n_spp_total,'label') <- 'Number of total species'

attr(tfddbasins_no_treaty$d_treaty,'label') <- 'Treaty == 0 : TFDD'

tfddbasins_no_treaty_fn <- file.path(tbldir,sprintf('tfddbasins_no_treaty_species_summary%s.dta',Sys.Date()))
haven::write_dta(tfddbasins_no_treaty,tfddbasins_no_treaty_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(tfddbasins_no_treaty),
  Label = sapply(tfddbasins_no_treaty, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('tfddbasins_no_treaty_species_summary_labels%s.csv',Sys.Date())), row.names = FALSE)

##
## Basins by River Basin Organization
##
tfddbasins_no_rbo <- master_tab %>%
  dplyr::select(species,basin_bids, d_endemic100, pthreat,
                area) %>%
  # need data
  dplyr::filter(!is.na(pthreat)) %>%
  dplyr::filter(!is.na(area)) %>%
  
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  # only transboundary basins
  dplyr::filter(basin_bids %in% c(tfdd_gid)) %>%
  # treaty dummy
  dplyr::mutate(d_RBO = ifelse(basin_bids %in% tfdd_rbo_bid,1,0)) %>%
  dplyr::select(-c(basin_bids)) %>%
  
  dplyr::group_by(species,pthreat,d_endemic100) %>%
  dplyr::summarize(d_sumRBO = sum(d_RBO,na.rm=TRUE),
                   d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE),
                   area = max(area,na.rm=TRUE)) %>%
  dplyr::ungroup() %>%
  dplyr::filter(d_sumRBO==0) %>%
  distinct() %>%
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
                d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n()) %>%
  dplyr::mutate(d_RBO = 0)


tfddbasins_no_rbo_fn <- file.path(tbldir,sprintf('tfddbasins_no_rbo_species_summary%s.csv',Sys.Date()))
write.csv(tfddbasins_no_rbo,tfddbasins_no_rbo_fn,row.names=F)

names(tfddbasins_no_rbo)
attr(tfddbasins_no_rbo$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(tfddbasins_no_rbo$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(tfddbasins_no_rbo$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(tfddbasins_no_rbo$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(tfddbasins_no_rbo$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(tfddbasins_no_rbo$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(tfddbasins_no_rbo$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(tfddbasins_no_rbo$n_spp_total,'label') <- 'Number of total species'

attr(tfddbasins_no_rbo$d_RBO,'label') <- 'River Basin Organization == 0 : TFDD'

tfddbasins_no_rbo_fn <- file.path(tbldir,sprintf('tfddbasins_no_rbo_species_summary%s.dta',Sys.Date()))
haven::write_dta(tfddbasins_no_rbo,tfddbasins_no_rbo_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(tfddbasins_no_rbo),
  Label = sapply(tfddbasins_no_rbo, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('tfddbasins_no_rbo_species_summary_labels%s.csv',Sys.Date())), row.names = FALSE)



##
## ADDED : NO RBO AND TREATY
##

# Basins by River Basin Organization AND TREATY
tfddbasins_no_rbo_and_treaty <- master_tab %>%
  dplyr::select(species,basin_bids, d_endemic100, pthreat,
                area) %>%
  # need data
  dplyr::filter(!is.na(pthreat)) %>%
  dplyr::filter(!is.na(area)) %>%
  
  # basins ids col has all entities that intersect
  tidyr::separate_rows(basin_bids, sep = ",") %>%
  dplyr::mutate(basin_bids = as.numeric(stringr::str_trim(basin_bids))) %>%
  # only transboundary basins
  dplyr::filter(basin_bids %in% c(tfdd_gid)) %>%
  # treaty or RBO dummy
  dplyr::mutate(d_RBO_or_treaty = ifelse(basin_bids %in% tfdd_yes_rbo_or_treaty_bid,1,0)) %>%
  dplyr::select(-c(basin_bids)) %>%
  
  # species can be present across basins... 
  dplyr::group_by(species,pthreat,d_endemic100) %>%
  dplyr::summarize(d_sumRBOorTreaty = sum(d_RBO_or_treaty,na.rm=TRUE),
                   d_endemic100 = max(d_endemic100,na.rm=TRUE),
                   pthreat = max(pthreat,na.rm=TRUE),
                   area = max(area,na.rm=TRUE)) %>%
  dplyr::ungroup() %>%
  dplyr::filter(d_sumRBOorTreaty==0) %>%
  distinct() %>%
  
  dplyr::mutate(d_smallocc50 = ifelse(area <= 50*50,1,0),
                d_tprob80 = ifelse(pthreat >= 80,1,0)) %>%
  dplyr::mutate(d_spp_small50xTprob80 = ifelse(d_smallocc50==1 & d_tprob80==1,1,0),
                d_spp_Endemic100xTprob80 = ifelse(d_endemic100==1 & d_tprob80==1,1,0),
                d_smallocc50xEndemic100 = ifelse(d_smallocc50==1 & d_endemic100==1,1,0),
                d_smallocc50xEndemic100xTprob80 = 
                  ifelse(d_smallocc50==1 & d_endemic100==1 & d_tprob80==1,1,0)
  ) %>%
  dplyr::summarize(n_spp_end100 = sum(d_endemic100,na.rm=T),
                   n_spp_small50 = sum(d_smallocc50,na.rm=T),
                   n_spp_tprob80 = sum(d_tprob80,na.rm=T),
                   
                   n_spp_small50xEndemic100 = sum(d_smallocc50xEndemic100,na.rm=T),
                   n_spp_small50xTprob80 = sum(d_spp_small50xTprob80,na.rm=T),
                   n_spp_Endemic100xTprob80 = sum(d_spp_Endemic100xTprob80,na.rm=T), 
                   
                   n_spp_small50xEndemic100xTprob80 = sum(d_smallocc50xEndemic100xTprob80,na.rm=T),
                   
                   n_spp_total = n()) %>%
  dplyr::mutate(d_no_RBO_and_treaty = 1)


tfddbasins_no_rbo_and_treaty_fn <- file.path(tbldir,sprintf('tfddbasins_no_rbo_and_treaty_species_summary%s.csv',Sys.Date()))
write.csv(tfddbasins_no_rbo_and_treaty,tfddbasins_no_rbo_and_treaty_fn,row.names=F)

names(tfddbasins_no_rbo_and_treaty)
attr(tfddbasins_no_rbo_and_treaty$n_spp_end100,'label') <- 'Number of endemics at 100%'
attr(tfddbasins_no_rbo_and_treaty$n_spp_small50,'label') <- 'Number of species with small occurrence regions (50x50)'
attr(tfddbasins_no_rbo_and_treaty$n_spp_tprob80,'label') <- 'Number of species with probability threat gte 80'

attr(tfddbasins_no_rbo_and_treaty$n_spp_small50xEndemic100,'label') <- 'Number of endemic species with small occurrence regions (50x50)'
attr(tfddbasins_no_rbo_and_treaty$n_spp_small50xTprob80,'label') <- 'Number of species with small occurrence regions (50x50) and tprob>=80'
attr(tfddbasins_no_rbo_and_treaty$n_spp_Endemic100xTprob80,'label') <- 'Number of endemic species with tprob>=80'

attr(tfddbasins_no_rbo_and_treaty$n_spp_small50xEndemic100xTprob80,'label') <- 'Number of endemic species with small occurrence regions (50x50) and tprob>=80'

attr(tfddbasins_no_rbo_and_treaty$n_spp_total,'label') <- 'Number of total species'

attr(tfddbasins_no_rbo_and_treaty$d_no_RBO_and_treaty,'label') <- 'River Basin Organization == 0 & Treaty == 0 : TFDD'

tfddbasins_no_rbo_and_treaty_dta_fn <- file.path(tbldir,sprintf('tfddbasins_no_rbo_and_treaty_species_summary%s.dta',Sys.Date()))
haven::write_dta(tfddbasins_no_rbo_and_treaty,tfddbasins_no_rbo_and_treaty_dta_fn)

# Create a table of labels
labels_table <- data.frame(
  Variable = names(tfddbasins_no_rbo_and_treaty),
  Label = sapply(tfddbasins_no_rbo_and_treaty, attr, "label")
)

# Export the labels table to CSV
write.csv(labels_table, file.path(tbldir,sprintf('tfddbasins_no_rbo_and_treaty_species_summary_labels%s.csv',Sys.Date())), row.names = FALSE)
